@@ -8,6 +8,7 @@
 #include "mlt++/Mlt.h"
 #include "renderjob.h"
 #include <QApplication>
+#include <QDebug>
 #include <QDir>
 #include <QDomDocument>
 
@@ -16,6 +17,7 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     QStringList args = app.arguments();
     QStringList preargs;
+    QString subtitleFile;
     if (args.count() >= 4) {
         // Remove program name
         args.removeFirst();
@@ -36,7 +38,7 @@ int main(int argc, char **argv)
         }
         int in = -1;
         int out = -1;
-        
+
         if (args.count() > 1 && args.at(0) == QLatin1String("-out")) {
             args.removeFirst();
             out = args.at(0).toInt();
@@ -47,11 +49,7 @@ int main(int argc, char **argv)
         if (args.count() > 5 && args.at(0) == QLatin1String("-split")) {
             args.removeFirst();
             // chunks to render
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            QStringList chunks = args.at(0).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
             QStringList chunks = args.at(0).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
             args.removeFirst();
             // chunk size in frames
             int chunkSize = args.at(0).toInt();
@@ -63,11 +61,7 @@ int main(int argc, char **argv)
             QString extension = args.at(0);
             args.removeFirst();
             // avformat consumer params
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            QStringList consumerParams = args.at(0).split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
             QStringList consumerParams = args.at(0).split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
             args.removeFirst();
             QDir baseFolder(target);
 
@@ -116,7 +110,7 @@ int main(int argc, char **argv)
                     chunks.removeFirst();
                 }
                 fprintf(stderr, "START:%d \n", frame.toInt());
-                QString fileName = QStringLiteral("%1.%2").arg(frame,extension);
+                QString fileName = QStringLiteral("%1.%2").arg(frame, extension);
                 if (baseFolder.exists(fileName)) {
                     // Don't overwrite an existing file
                     fprintf(stderr, "DONE:%d \n", frame.toInt());
@@ -146,8 +140,12 @@ int main(int argc, char **argv)
             fprintf(stderr, "+ + + RENDERING FINISHED + + + \n");
             return 0;
         }
-        
-        // older MLT version, does not support embedded consumer in/out in xml, and current 
+        if (args.count() > 1 && args.at(0) == QLatin1String("-subtitle")) {
+            args.removeFirst();
+            subtitleFile = args.takeFirst();
+        }
+
+        // older MLT version, does not support embedded consumer in/out in xml, and current
         // MLT (6.16) does not pass it onto the multi / movit consumer, so read it manually and enforce
         LocaleHandling::resetAllLocale();
         QFile f(playlist);
@@ -162,12 +160,13 @@ int main(int argc, char **argv)
                 playlist.append(QStringLiteral("?multi=1"));
             }
         }
-        auto *rJob = new RenderJob(render, playlist, target, pid, in, out, qApp);
-        rJob->start();
+        auto *rJob = new RenderJob(render, playlist, target, pid, in, out, subtitleFile, &app);
         QObject::connect(rJob, &RenderJob::renderingFinished, rJob, [&]() {
             rJob->deleteLater();
             app.quit();
         });
+        app.setQuitOnLastWindowClosed(false);
+        QMetaObject::invokeMethod(rJob, "start", Qt::QueuedConnection);
         return app.exec();
     } else {
         fprintf(stderr,
