@@ -4,18 +4,18 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef RENDERJOB_H
-#define RENDERJOB_H
+#pragma once
 
 #ifdef NODBUS
 #include <QLocalSocket>
 #else
 #include <QDBusInterface>
 #endif
+#include <QDateTime>
+#include <QEventLoop>
+#include <QFile>
 #include <QObject>
 #include <QProcess>
-#include <QDateTime>
-#include <QFile>
 // Testing
 #include <QTextStream>
 
@@ -24,7 +24,8 @@ class RenderJob : public QObject
     Q_OBJECT
 
 public:
-    RenderJob(const QString &render, const QString &scenelist, const QString &target, int pid = -1, int in = -1, int out = -1, QObject *parent = nullptr);
+    RenderJob(const QString &render, const QString &scenelist, const QString &target, int pid = -1, int in = -1, int out = -1,
+              const QString &subtitleFile = QString(), QObject *parent = nullptr);
     ~RenderJob() override;
 
 public slots:
@@ -36,6 +37,8 @@ private slots:
     void slotAbort();
     void slotAbort(const QString &url);
     void slotCheckProcess(QProcess::ProcessState state);
+    void slotCheckSubtitleProcess(int exitCode, QProcess::ExitStatus exitStatus);
+    void receivedSubtitleProgress();
 
 private:
     QString m_scenelist;
@@ -60,7 +63,11 @@ private:
     /** @brief The process id of the Kdenlive instance, used to get the dbus service. */
     int m_pid;
     bool m_dualpass;
+    QString m_subtitleFile;
+    QString m_temporaryRenderFile;
     QProcess *m_renderProcess;
+    QProcess *m_subsProcess;
+    QEventLoop m_looper;
     QString m_errorMessage;
     QList<QVariant> m_dbusargs;
     QDateTime m_startTime;
@@ -73,10 +80,9 @@ private:
     void initKdenliveDbusInterface();
 #endif
     void sendFinish(int status, const QString &error);
+    void updateProgress(int speed = -1);
     void sendProgress();
 
 signals:
     void renderingFinished();
 };
-
-#endif
