@@ -21,38 +21,49 @@ class AssetListWidget : public QQuickWidget
     Q_OBJECT
     /** @brief Should the descriptive info box be displayed
      */
+    Q_PROPERTY(bool showDescription READ showDescription WRITE setShowDescription NOTIFY showDescriptionChanged)
 
 public:
     AssetListWidget(QWidget *parent = Q_NULLPTR);
     ~AssetListWidget() override;
 
+    virtual bool isEffect() const = 0;
+
     /** @brief Returns the name of the asset given its model index */
-    QString getName(const QModelIndex &index) const;
+    Q_INVOKABLE QString getName(const QModelIndex &index) const;
 
     /** @brief Returns true if this effect belongs to favorites */
-    bool isFavorite(const QModelIndex &index) const;
+    Q_INVOKABLE bool isFavorite(const QModelIndex &index) const;
 
     /** @brief Sets whether this effect belongs to favorites */
-    void setFavorite(const QModelIndex &index, bool favorite = true, bool isEffect = true);
+    Q_INVOKABLE void setFavorite(const QModelIndex &index, bool favorite = true);
 
     /** @brief Delete a custom effect */
-    void deleteCustomEffect(const QModelIndex &index);
-    virtual void reloadCustomEffectIx(const QModelIndex &index) = 0;
-    virtual void editCustomAsset(const QModelIndex &index) = 0;
+    Q_INVOKABLE void deleteCustomEffect(const QModelIndex &index);
+    Q_INVOKABLE virtual void reloadCustomEffectIx(const QModelIndex &index) = 0;
+    Q_INVOKABLE virtual void editCustomAsset(const QModelIndex &index) = 0;
     /** @brief Returns the description of the asset given its model index */
-    QString getDescription(bool isEffect, const QModelIndex &index) const;
+    Q_INVOKABLE QString getDescription(const QModelIndex &index) const;
 
     /** @brief Sets the pattern against which the assets' names are filtered */
-    void setFilterName(const QString &pattern);
+    Q_INVOKABLE void setFilterName(const QString &pattern);
+
+    Q_INVOKABLE virtual void setFilterType(const QString &type) = 0;
 
     /** @brief Return mime type used for drag and drop. It can be kdenlive/effect,
-      kdenlive/composition or kdenlive/transition*/
-    virtual QString getMimeType(const QString &assetId) const = 0;
+     *  kdenlive/composition or kdenlive/transition
+     */
+    Q_INVOKABLE virtual QString getMimeType(const QString &assetId) const = 0;
     virtual bool isAudio(const QString &assetId) const = 0;
 
-    QVariantMap getMimeData(const QString &assetId) const;
+    Q_INVOKABLE QVariantMap getMimeData(const QString &assetId) const;
 
-    void activate(const QModelIndex &ix);
+    Q_INVOKABLE void activate(const QModelIndex &ix);
+
+    /** @brief Should the descriptive info box be displayed
+     */
+    bool showDescription() const;
+    void setShowDescription(bool show);
 
     /** @brief Rebuild the view by resetting the source. Is there a better way? */
     void reset();
@@ -66,4 +77,6 @@ protected:
 
 signals:
     void activateAsset(const QVariantMap data);
+    void showDescriptionChanged();
+    void reloadFavorites();
 };
