@@ -622,3 +622,14 @@ QModelIndex KeyframeModelList::getIndexAtRow(int row)
     }
     return QModelIndex();
 }
+
+std::vector<QPersistentModelIndex> KeyframeModelList::getIndexes()
+{
+    std::vector<QPersistentModelIndex> keys;
+    keys.reserve(m_parameters.size());
+
+    for (auto kv : m_parameters) {
+        keys.push_back(kv.first);
+    }
+    return keys;
+}
