@@ -5,8 +5,7 @@ This file is part of Kdenlive. See www.kdenlive.org.
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef RECTHELPER_H
-#define RECTHELPER_H
+#pragma once
 
 #include "assets/keyframes/model/keyframemonitorhelper.hpp"
 
@@ -43,5 +42,3 @@ public:
 private slots:
     void slotUpdateFromMonitorRect(const QRect &rect);
 };
-
-#endif
