@@ -111,6 +111,11 @@ void KeyframeView::initKeyframePos()
     emit atKeyframe(m_model->hasKeyframe(m_position), m_model->singleKeyframe());
 }
 
+const QVector<int> KeyframeView::selectedKeyframesIndexes()
+{
+    return m_model->selectedKeyframes();
+}
+
 void KeyframeView::slotDuplicateKeyframe()
 {
     int offset = pCore->getItemIn(m_model->getOwnerId());
@@ -297,12 +302,21 @@ void KeyframeView::mousePressEvent(QMouseEvent *event)
     double zoomStart = m_zoomHandle.x() * (width() - 2 * m_offset);
     double zoomEnd = m_zoomHandle.y() * (width() - 2 * m_offset);
     double zoomFactor = (width() - 2 * m_offset) / (zoomEnd - zoomStart);
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     int pos = int(((event->x() - m_offset) / zoomFactor + zoomStart) / m_scale);
+#else
+    int pos = int(((event->position().x() - m_offset) / zoomFactor + zoomStart) / m_scale);
+#endif
     pos = qBound(0, pos, m_duration - 1);
     m_moveKeyframeMode = false;
     m_keyframeZonePress = false;
     if (event->button() == Qt::LeftButton) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (event->y() < m_lineHeight) {
+#else
+        if (event->position().y() < m_lineHeight) {
+#endif
             // mouse click in keyframes area
             bool ok;
             GenTime position(pos + offset, pCore->getCurrentFps());
@@ -344,10 +358,18 @@ void KeyframeView::mousePressEvent(QMouseEvent *event)
             m_model->setSelectedKeyframes({});
             m_model->setActiveKeyframe(-1);
             m_currentKeyframeOriginal = -1;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         } else if (event->y() > m_zoomHeight + 2) {
+#else
+        } else if (event->position().y() > m_zoomHeight + 2) {
+#endif
             // click on zoom area
             if (m_hoverZoom) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 m_clickOffset = (double(event->x()) - m_offset) / (width() - 2 * m_offset);
+#else
+                m_clickOffset = (double(event->position().x()) - m_offset) / (width() - 2 * m_offset);
+#endif
             }
             // When not zoomed, allow seek by clicking on zoombar
             if (qFuzzyCompare(m_zoomFactor, 1.) && pos != m_position && !m_hoverZoomIn && !m_hoverZoomOut) {
@@ -355,7 +377,11 @@ void KeyframeView::mousePressEvent(QMouseEvent *event)
             }
             return;
         }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     } else if (event->button() == Qt::RightButton && event->y() > m_zoomHeight + 2) {
+#else
+    } else if (event->button() == Qt::RightButton && event->position().y() > m_zoomHeight + 2) {
+#endif
         // Right click on zoom, switch between no zoom and last zoom status
         if (m_zoomHandle == QPointF(0, 1)) {
             if (!m_lastZoomHandle.isNull()) {
@@ -382,25 +408,41 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
     double zoomStart = m_zoomHandle.x() * (width() - 2 * m_offset);
     double zoomEnd = m_zoomHandle.y() * (width() - 2 * m_offset);
     double zoomFactor = (width() - 2 * m_offset) / (zoomEnd - zoomStart);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     int pos = int(((double(event->x()) - m_offset) / zoomFactor + zoomStart) / m_scale);
+#else
+    int pos = int(((double(event->position().x()) - m_offset) / zoomFactor + zoomStart) / m_scale);
+#endif
     pos = qBound(0, pos, m_duration - 1);
     GenTime position(pos + offset, pCore->getCurrentFps());
     if ((event->buttons() & Qt::LeftButton) != 0u) {
         if (m_hoverZoomIn || m_hoverZoomOut || m_hoverZoom) {
             // Moving zoom handles
             if (m_hoverZoomIn) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 m_zoomHandle.setX(qMin(qMax(0., double(event->x() - m_offset) / (width() - 2 * m_offset)), m_zoomHandle.y() - 0.015));
+#else
+                m_zoomHandle.setX(qMin(qMax(0., double(event->position().x() - m_offset) / (width() - 2 * m_offset)), m_zoomHandle.y() - 0.015));
+#endif
                 update();
                 return;
             }
             if (m_hoverZoomOut) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 m_zoomHandle.setY(qMax(qMin(1., double(event->x() - m_offset) / (width() - 2 * m_offset)), m_zoomHandle.x() + 0.015));
+#else
+                m_zoomHandle.setY(qMax(qMin(1., double(event->position().x() - m_offset) / (width() - 2 * m_offset)), m_zoomHandle.x() + 0.015));
+#endif
                 update();
                 return;
             }
             // moving zoom zone
             if (m_hoverZoom) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 double clickOffset = (double(event->x()) - m_offset) / (width() - 2 * m_offset) - m_clickOffset;
+#else
+                double clickOffset = (double(event->position().x()) - m_offset) / (width() - 2 * m_offset) - m_clickOffset;
+#endif
                 double newX = m_zoomHandle.x() + clickOffset;
                 if (newX < 0) {
                     clickOffset = -m_zoomHandle.x();
@@ -412,7 +454,11 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
                     newY = 1;
                     newX = m_zoomHandle.x() + clickOffset;
                 }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 m_clickOffset = (double(event->x()) - m_offset) / (width() - 2 * m_offset);
+#else
+                m_clickOffset = (double(event->position().x()) - m_offset) / (width() - 2 * m_offset);
+#endif
                 m_zoomHandle = QPointF(newX, newY);
                 update();
             }
@@ -485,7 +531,11 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
         }
         return;
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (event->y() < m_lineHeight) {
+#else
+    if (event->position().y() < m_lineHeight) {
+#endif
         bool ok;
         auto keyframe = m_model->getClosestKeyframe(position, &ok);
         if (ok && qAbs(((position.frames(pCore->getCurrentFps()) - keyframe.first.frames(pCore->getCurrentFps())) * m_scale) * m_zoomFactor) <
@@ -499,9 +549,15 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
             return;
         }
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (event->y() > m_zoomHeight + 2) {
         // Moving in zoom area
         if (qAbs(event->x() - m_offset - (m_zoomHandle.x() * (width() - 2 * m_offset))) < QApplication::startDragDistance()) {
+#else
+    if (event->position().y() > m_zoomHeight + 2) {
+        // Moving in zoom area
+        if (qAbs(event->position().x() - m_offset - (m_zoomHandle.x() * (width() - 2 * m_offset))) < QApplication::startDragDistance()) {
+#endif
             setCursor(Qt::SizeHorCursor);
             m_hoverZoomIn = true;
             m_hoverZoomOut = false;
@@ -509,7 +565,11 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
             update();
             return;
         }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (qAbs(event->x() - m_offset - (m_zoomHandle.y() * (width() - 2 * m_offset))) < QApplication::startDragDistance()) {
+#else
+        if (qAbs(event->position().x() - m_offset - (m_zoomHandle.y() * (width() - 2 * m_offset))) < QApplication::startDragDistance()) {
+#endif
             setCursor(Qt::SizeHorCursor);
             m_hoverZoomOut = true;
             m_hoverZoomIn = false;
@@ -517,8 +577,13 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
             update();
             return;
         }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (m_zoomHandle != QPointF(0, 1) && event->x() > m_offset + (m_zoomHandle.x() * (width() - 2 * m_offset)) &&
             event->x() < m_offset + (m_zoomHandle.y() * (width() - 2 * m_offset))) {
+#else
+        if (m_zoomHandle != QPointF(0, 1) && event->position().x() > m_offset + (m_zoomHandle.x() * (width() - 2 * m_offset)) &&
+            event->position().x() < m_offset + (m_zoomHandle.y() * (width() - 2 * m_offset))) {
+#endif
             setCursor(Qt::PointingHandCursor);
             m_hoverZoom = true;
             m_hoverZoomIn = false;
@@ -585,12 +650,20 @@ void KeyframeView::mouseReleaseEvent(QMouseEvent *event)
 
 void KeyframeView::mouseDoubleClickEvent(QMouseEvent *event)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (event->button() == Qt::LeftButton && event->y() < m_lineHeight) {
+#else
+    if (event->button() == Qt::LeftButton && event->position().y() < m_lineHeight) {
+#endif
         int offset = pCore->getItemIn(m_model->getOwnerId());
         double zoomStart = m_zoomHandle.x() * (width() - 2 * m_offset);
         double zoomEnd = m_zoomHandle.y() * (width() - 2 * m_offset);
         double zoomFactor = (width() - 2 * m_offset) / (zoomEnd - zoomStart);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         int pos = int(((event->x() - m_offset) / zoomFactor + zoomStart) / m_scale);
+#else
+        int pos = int(((event->position().x() - m_offset) / zoomFactor + zoomStart) / m_scale);
+#endif
         pos = qBound(0, pos, m_duration - 1);
         GenTime position(pos + offset, pCore->getCurrentFps());
         bool ok;
