@@ -83,7 +83,8 @@ bool AssetCommand::mergeWith(const QUndoCommand *other)
     return true;
 }
 
-AssetMultiCommand::AssetMultiCommand(const std::shared_ptr<AssetParameterModel> &model, const QList <QModelIndex> &indexes, const QStringList &values, QUndoCommand *parent)
+AssetMultiCommand::AssetMultiCommand(const std::shared_ptr<AssetParameterModel> &model, const QList<QModelIndex> &indexes, const QStringList &values,
+                                     QUndoCommand *parent)
     : QUndoCommand(parent)
     , m_model(model)
     , m_indexes(indexes)
@@ -91,7 +92,7 @@ AssetMultiCommand::AssetMultiCommand(const std::shared_ptr<AssetParameterModel>
     , m_updateView(false)
     , m_stamp(QTime::currentTime())
 {
-    qDebug()<<"CREATING MULTIPLE COMMAND!!!\nVALUES: "<<m_values;
+    qDebug() << "CREATING MULTIPLE COMMAND!!!\nVALUES: " << m_values;
     m_name = m_model->data(m_indexes.first(), AssetParameterModel::NameRole).toString();
     const QString id = model->getAssetId();
     if (EffectsRepository::get()->exists(id)) {
@@ -134,7 +135,7 @@ int AssetMultiCommand::id() const
 // virtual
 bool AssetMultiCommand::mergeWith(const QUndoCommand *other)
 {
-    if (other->id() != id() || static_cast<const AssetMultiCommand *>(other)->m_indexes != m_indexes  ||
+    if (other->id() != id() || static_cast<const AssetMultiCommand *>(other)->m_indexes != m_indexes ||
         m_stamp.msecsTo(static_cast<const AssetMultiCommand *>(other)->m_stamp) > 3000) {
         return false;
     }
