@@ -76,8 +76,7 @@ void AssetParameterView::setModel(const std::shared_ptr<AssetParameterModel> &mo
     for (int i = 0; i < model->rowCount(); ++i) {
         QModelIndex index = model->index(i, 0);
         auto type = model->data(index, AssetParameterModel::TypeRole).value<ParamType>();
-        if (m_mainKeyframeWidget && (type == ParamType::Geometry || type == ParamType::Animated || type == ParamType::RestrictedAnim ||
-                                     type == ParamType::KeyframeParam || type == ParamType::ColorWheel)) {
+        if (m_mainKeyframeWidget && (AssetParameterModel::isAnimated(type) || type == ParamType::Geometry)) {
             // Keyframe widget can have some extra params that shouldn't build a new widget
             qDebug() << "// FOUND ADDED PARAM";
             if (type != ParamType::ColorWheel) {
@@ -94,19 +93,26 @@ void AssetParameterView::setModel(const std::shared_ptr<AssetParameterModel> &mo
                 setFixedHeight(contentHeight());
                 emit updateHeight();
             });
-            m_lay->addWidget(w);
-            if (type == ParamType::KeyframeParam || type == ParamType::AnimatedRect || type == ParamType::Roto_spline || type == ParamType::ColorWheel) {
+            if (AssetParameterModel::isAnimated(type)) {
                 m_mainKeyframeWidget = static_cast<KeyframeWidget *>(w);
                 connect(this, &AssetParameterView::nextKeyframe, m_mainKeyframeWidget, &KeyframeWidget::goToNext);
                 connect(this, &AssetParameterView::previousKeyframe, m_mainKeyframeWidget, &KeyframeWidget::goToPrevious);
                 connect(this, &AssetParameterView::addRemoveKeyframe, m_mainKeyframeWidget, &KeyframeWidget::addRemove);
+                connect(this, &AssetParameterView::sendStandardCommand, m_mainKeyframeWidget, &KeyframeWidget::sendStandardCommand);
             } else {
+                m_lay->addWidget(w);
                 minHeight += w->minimumHeight();
             }
             m_widgets.push_back(w);
         }
     }
-    setMinimumHeight(m_mainKeyframeWidget ? m_mainKeyframeWidget->minimumHeight() + minHeight : minHeight);
+    if (m_mainKeyframeWidget) {
+        // Add keyframe widget to the bottom to have a clear seperation
+        // between animated an non-animated params
+        m_lay->addWidget(m_mainKeyframeWidget);
+        minHeight += m_mainKeyframeWidget->minimumHeight();
+    }
+    setMinimumHeight(minHeight);
     if (addSpacer) {
         m_lay->addStretch();
     }
@@ -123,7 +129,8 @@ QVector<QPair<QString, QVariant>> AssetParameterView::getDefaultValues() const
         QString name = m_model->data(index, AssetParameterModel::NameRole).toString();
         auto type = m_model->data(index, AssetParameterModel::TypeRole).value<ParamType>();
         QVariant defaultValue = m_model->data(index, AssetParameterModel::DefaultRole);
-        if (type == ParamType::KeyframeParam || type == ParamType::AnimatedRect || type == ParamType::ColorWheel) {
+        if (AssetParameterModel::isAnimated(type) && type != ParamType::Roto_spline) {
+            // Roto_spline keyframes are stored as JSON so do not apply this to roto
             QString val = defaultValue.toString();
             if (!val.contains(QLatin1Char('='))) {
                 val.prepend(QStringLiteral("%1=").arg(m_model->data(index, AssetParameterModel::ParentInRole).toInt()));
@@ -258,21 +265,6 @@ MonitorSceneType AssetParameterView::needsMonitorEffectScene() const
     return MonitorSceneDefault;
 }
 
-/*void AssetParameterView::initKeyframeView()
-{
-    if (m_mainKeyframeWidget) {
-        m_mainKeyframeWidget->initMonitor();
-    } else {
-        for (int i = 0; i < m_model->rowCount(); ++i) {
-        QModelIndex index = m_model->index(i, 0);
-        auto type = m_model->data(index, AssetParameterModel::TypeRole).value<ParamType>();
-        if (type == ParamType::Geometry) {
-            return MonitorSceneGeometry;
-        }
-    }
-    }
-}*/
-
 void AssetParameterView::slotRefresh()
 {
     refresh(m_model->index(0, 0), m_model->index(m_model->rowCount() - 1, 0), {});
