@@ -29,10 +29,8 @@ ListParamWidget::ListParamWidget(std::shared_ptr<AssetParameterModel> model, QMo
 
     // emit the signal of the base class when appropriate
     // The connection is ugly because the signal "currentIndexChanged" is overloaded in QComboBox
-    connect(this->m_list, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
-            this, [this](int) {
-                emit valueChanged(m_index, m_list->itemData(m_list->currentIndex()).toString(), true);
-    });
+    connect(this->m_list, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
+            [this](int) { emit valueChanged(m_index, m_list->itemData(m_list->currentIndex()).toString(), true); });
 }
 
 void ListParamWidget::setCurrentIndex(int index)
@@ -117,7 +115,7 @@ void ListParamWidget::slotRefresh()
         }
         if (!value.isEmpty()) {
             int ix = m_list->findData(value);
-            if (ix > -1)  {
+            if (ix > -1) {
                 m_list->setCurrentIndex(ix);
             }
         }
