@@ -5,8 +5,7 @@
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef MULTISWITCHPARAMWIDGET_H
-#define MULTISWITCHPARAMWIDGET_H
+#pragma once
 
 #include "abstractparamwidget.hpp"
 #include "ui_boolparamwidget_ui.h"
@@ -36,5 +35,3 @@ public slots:
      */
     void slotRefresh() override;
 };
-
-#endif
