@@ -3,8 +3,7 @@ SPDX-FileCopyrightText: 2016 Jean-Baptiste Mardelle <jb@kdenlive.org>
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef AUDIOLEVELWIDGET_H
-#define AUDIOLEVELWIDGET_H
+#pragma once
 
 #include <QWidget>
 #include <memory>
@@ -27,7 +26,11 @@ protected:
     void paintEvent(QPaintEvent *) override;
     void resizeEvent(QResizeEvent *event) override;
     void changeEvent(QEvent *event) override;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    void enterEvent(QEnterEvent *event) override;
+#else
     void enterEvent(QEvent *event) override;
+#endif
     void leaveEvent(QEvent *event) override;
 
 private:
@@ -49,5 +52,3 @@ private:
 public slots:
     void setAudioValues(const QVector<double> &values);
 };
-
-#endif
