@@ -37,10 +37,11 @@ Generators::Generators(const QString &path, QWidget *parent)
     , m_container(nullptr)
     , m_preview(nullptr)
 {
-    QFile file(path);
     QDomDocument doc;
-    doc.setContent(&file, false);
-    file.close();
+    if (!Xml::docContentFromFile(doc, path, false)) {
+        return;
+    }
+
     QDomElement base = doc.documentElement();
     if (base.tagName() == QLatin1String("generator")) {
         QString generatorTag = base.attribute(QStringLiteral("tag"));
@@ -54,7 +55,7 @@ Generators::Generators(const QString &path, QWidget *parent)
         m_preview->setPixmap(m_pixmap.scaledToWidth(m_preview->width()));
         auto *hlay = new QHBoxLayout;
         hlay->addWidget(new QLabel(i18n("Duration:")));
-        m_timePos = new TimecodeDisplay(pCore->timecode(), this);
+        m_timePos = new TimecodeDisplay(this);
         if (base.hasAttribute(QStringLiteral("updateonduration"))) {
             connect(m_timePos, &TimecodeDisplay::timeCodeEditingFinished, this, &Generators::updateDuration);
         }
@@ -129,9 +130,10 @@ QPair<QString, QString> Generators::parseGenerator(const QString &path, const QS
 {
     QPair<QString, QString> result;
     QDomDocument doc;
-    QFile file(path);
-    doc.setContent(&file, false);
-    file.close();
+    if (!Xml::docContentFromFile(doc, path, false)) {
+        return result;
+    }
+
     QDomElement base = doc.documentElement();
     if (base.tagName() == QLatin1String("generator")) {
         QString generatorTag = base.attribute(QStringLiteral("tag"));
