@@ -5,12 +5,11 @@ This file is part of Kdenlive. See www.kdenlive.org.
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef KDENLIVE_TAGWIDGET_H
-#define KDENLIVE_TAGWIDGET_H
+#pragma once
 
+#include <QScrollArea>
 #include <QToolButton>
 
-
 /** @class DragButton
     @brief A draggable QToolButton subclass
  */
@@ -41,7 +40,6 @@ signals:
     void switchTag(const QString &tag, bool add);
 };
 
-
 /** @class TagWidget
     @brief The tag widget takes care context menu tagging
  */
@@ -52,15 +50,13 @@ class TagWidget : public QWidget
 public:
     explicit TagWidget(QWidget *parent = nullptr);
     void setTagData(const QString &tagData = QString());
-    void rebuildTags(const QMap <QString, QString> &newTags);
+    void rebuildTags(const QMap<int, QStringList> &newTags);
 
 private:
-    QList <DragButton *> tags;
+    QList<DragButton *> tags;
     void showTagsConfig();
 
 signals:
     void switchTag(const QString &tag, bool add);
-    void updateProjectTags(QMap <QString, QString> newTags);
+    void updateProjectTags(const QMap<int, QStringList> &oldTags, const QMap<int, QStringList> &newTags);
 };
-
-#endif
