@@ -102,7 +102,7 @@ public:
     MainWindow *window();
 
     /** @brief Open a file using an external app. */
-    QString openExternalApp(const QString &appPath, const QStringList args);
+    QString openExternalApp(QString appPath, const QStringList args);
 
     /** @brief Returns a pointer to the project manager. */
     ProjectManager *projectManager();
@@ -280,6 +280,8 @@ public:
     MixAlignment getMixAlign(int cid) const;
     /** @brief Closing current document, do some cleanup */
     void cleanup();
+    /** @brief Create the dock widgets */
+    void buildDocks();
 #if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 98, 0)
     /** @brief Instantiates a "Get Hot New Stuff" dialog.
      * @param configFile configuration file for KNewStuff
@@ -343,6 +345,8 @@ public slots:
     void triggerAction(const QString &name);
     /** @brief Get an action's descriptive text by its actionCollection name */
     const QString actionText(const QString &name);
+    /** @brief Add an action to the app's actionCollection */
+    void addActionToCollection(const QString &name, QAction *action);
     /** @brief display a user info/warning message in the project bin */
     void displayBinMessage(const QString &text, int type, const QList<QAction *> &actions = QList<QAction *>(), bool showClose = false, BinMessage::BinCategory messageCategory = BinMessage::BinCategory::NoMessage);
     void displayBinLogMessage(const QString &text, int type, const QString logInfo);
