@@ -27,6 +27,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "encodingprofilesdialog.h"
 
 class ProfileWidget;
+class GuideCategories;
 class KJob;
 
 class SpeechList : public QListWidget
@@ -82,7 +83,7 @@ private slots:
     void slotSetTranscodeProfile();
     void slotShuttleModified();
     void slotDialogModified();
-    void slotEnableCaptureFolder();
+    void slotEnableCaptureFolder(int ix);
     void slotEnableLibraryFolder();
     void slotEnableVideoFolder(int ix);
     void slotUpdatev4lDevice();
@@ -123,6 +124,7 @@ private:
     Ui::ConfigProxy_UI m_configProxy;
     Ui::ConfigSpeech_UI m_configSpeech;
     SpeechList *m_speechListWidget;
+    GuideCategories *m_guidesCategories;
     ProfileWidget *m_pw;
     KProcess m_readProcess;
     QAction *m_voskAction;
@@ -132,7 +134,7 @@ private:
     SpeechToText *m_stt;
     QMap<QString, QString> m_mappable_actions;
     QVector<QComboBox *> m_shuttle_buttons;
-    EncodingProfilesChooser *m_tlPreviewProfiles;
+    EncodingTimelinePreviewProfilesChooser *m_tlPreviewProfiles;
     EncodingProfilesChooser *m_proxyProfiles;
     EncodingProfilesChooser *m_decklinkProfiles;
     EncodingProfilesChooser *m_v4lProfiles;
