@@ -20,7 +20,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "klocalizedstring.h"
 
-MarkerDialog::MarkerDialog(ClipController *clip, const CommentedTime &t, const Timecode &tc, const QString &caption, QWidget *parent)
+MarkerDialog::MarkerDialog(ClipController *clip, const CommentedTime &t, const QString &caption, bool allowMultipleMarksers, QWidget *parent)
     : QDialog(parent)
     , m_clip(clip)
 {
@@ -29,19 +29,13 @@ MarkerDialog::MarkerDialog(ClipController *clip, const CommentedTime &t, const T
     setWindowTitle(caption);
 
     // Set  up categories
-    static std::array<QColor, 9> markerTypes = pCore->projectManager()->getGuideModel()->markerTypes;
-    QPixmap pixmap(32, 32);
-    for (uint i = 0; i < markerTypes.size(); ++i) {
-        pixmap.fill(markerTypes[size_t(i)]);
-        QIcon colorIcon(pixmap);
-        marker_type->addItem(colorIcon, i18n("Category %1", i));
-    }
-    marker_type->setCurrentIndex(t.markerType());
+    marker_category->setCurrentCategory(t.markerType());
 
-    m_in = new TimecodeDisplay(true, this);
-    inputLayout->addWidget(m_in);
     m_in->setValue(t.time());
-
+    if (!allowMultipleMarksers) {
+        multimarker_box->setVisible(false);
+    }
+    interval->setValue(GenTime(KdenliveSettings::multipleguidesinterval()));
     m_previewTimer = new QTimer(this);
 
     if (m_clip != nullptr) {
@@ -112,6 +106,21 @@ QImage MarkerDialog::markerImage() const
 
 CommentedTime MarkerDialog::newMarker()
 {
-    KdenliveSettings::setDefault_marker_type(marker_type->currentIndex());
-    return CommentedTime(m_in->gentime(), marker_comment->text(), marker_type->currentIndex());
+    KdenliveSettings::setDefault_marker_type(marker_category->currentCategory());
+    return CommentedTime(m_in->gentime(), marker_comment->text(), marker_category->currentCategory());
+}
+
+GenTime MarkerDialog::getInterval() const
+{
+    return interval->gentime();
+}
+
+int MarkerDialog::getOccurrences() const
+{
+    return occurrences->value();
+}
+
+bool MarkerDialog::addMultiMarker() const
+{
+    return multimarker_box->isExpanded();
 }
