@@ -16,10 +16,12 @@ class Menu;
 }
 #endif
 
-#include "definitions.h"
 #include "bin/model/markerlistmodel.hpp"
-#include "ui_renderwidget_ui.h"
+#include "definitions.h"
 #include "renderpresets/tree/renderpresettreemodel.hpp"
+#include "ui_renderwidget_ui.h"
+#include <knewstuff_version.h>
+#include <KNSWidgets/Button>
 
 class QDomElement;
 class QKeyEvent;
@@ -146,7 +148,9 @@ public slots:
     void reloadGuides();
     /** @brief Adjust render file name to current project name. */
     void resetRenderPath(const QString &path);
-    
+    /** @brief Update metadata tooltip with current values. */
+    void updateMetadataToolTip();
+
 private slots:
     /**
      * Will be called when the user selects an output file via the file dialog.
