@@ -3,9 +3,9 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef SPLASH_H
-#define SPLASH_H
+#pragma once
 
+#include <QPixmap>
 #include <QSplashScreen>
 #include <QStyleOptionProgressBar>
 
@@ -22,10 +22,9 @@ public slots:
 
 private:
     int m_progress;
+    QPixmap m_pixmap;
     QStyleOptionProgressBar m_pbStyle;
 
 protected:
     void drawContents(QPainter *painter) override;
 };
-
-#endif
