@@ -51,9 +51,6 @@ private slots:
 private:
     std::shared_ptr<SubtitleModel> m_model;
     int m_activeSub{-1};
-    TimecodeDisplay *m_position;
-    TimecodeDisplay *m_endPosition;
-    TimecodeDisplay *m_duration;
     GenTime m_startPos;
     GenTime m_endPos;
 
