@@ -5,8 +5,7 @@ This file is part of Kdenlive. See www.kdenlive.org.
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef TITLETEMPLATEDIALOG_H
-#define TITLETEMPLATEDIALOG_H
+#pragma once
 
 #include "ui_templateclip_ui.h"
 
@@ -30,5 +29,3 @@ private:
 private slots:
     void updatePreview();
 };
-
-#endif
