@@ -1,7 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2016 Jean-Baptiste Mardelle <jb@kdenlive.org>
-
-SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "wizard.h"
@@ -12,25 +11,23 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "profilesdialog.h"
 
 #include "utils/thememanager.h"
-#ifdef USE_V4L
-#include "capture/v4lcapture.h"
-#endif
 #include "core.h"
 #include <config-kdenlive.h>
 
 #include <framework/mlt_version.h>
 #include <mlt++/Mlt.h>
 
+#include <KLocalizedString>
 #include <KMessageWidget>
 #include <KProcess>
 #include <KRun>
-#include <klocalizedstring.h>
 
 #include "kdenlive_debug.h"
 #include <QApplication>
 #include <QCheckBox>
 #include <QFile>
 #include <QLabel>
+#include <QListWidget>
 #include <QMimeDatabase>
 #include <QMimeType>
 #include <QPushButton>
@@ -38,10 +35,12 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QTemporaryFile>
 #include <QTimer>
 #include <QXmlStreamWriter>
-#include <kio_version.h>
 
-#if KIO_VERSION >= QT_VERSION_CHECK(5,71,0)
 #include <KIO/OpenUrlJob>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
 #endif
 
@@ -84,9 +83,6 @@ Wizard::Wizard(bool autoClose, QWidget *parent)
     m_page->setLayout(m_startLayout);
     addPage(m_page);
 
-    /*QWizardPage *page2 = new QWizardPage;
-    page2->setTitle(i18n("Video Standard"));
-    m_standard.setupUi(page2);*/
     setButtonText(QWizard::CancelButton, i18n("Abort"));
     setButtonText(QWizard::FinishButton, i18n("OK"));
     slotCheckMlt();
@@ -186,196 +182,7 @@ Wizard::Wizard(bool autoClose, QWidget *parent)
         m_startLayout->addWidget(errorLabel);
         errorLabel->show();
     }
-    // build profiles lists
-    /*QMap<QString, QString> profilesInfo = ProfilesDialog::getProfilesInfo();
-    QMap<QString, QString>::const_iterator i = profilesInfo.constBegin();
-    while (i != profilesInfo.constEnd()) {
-        QMap< QString, QString > profileData = ProfilesDialog::getSettingsFromFile(i.key());
-        if (profileData.value(QStringLiteral("width")) == QLatin1String("720")) m_dvProfiles.insert(i.value(), i.key());
-        else if (profileData.value(QStringLiteral("width")).toInt() >= 1080) m_hdvProfiles.insert(i.value(), i.key());
-        else m_otherProfiles.insert(i.value(), i.key());
-        ++i;
-    }
 
-    m_standard.button_all->setChecked(true);
-    connect(m_standard.button_all, SIGNAL(toggled(bool)), this, SLOT(slotCheckStandard()));
-    connect(m_standard.button_hdv, SIGNAL(toggled(bool)), this, SLOT(slotCheckStandard()));
-    connect(m_standard.button_dv, SIGNAL(toggled(bool)), this, SLOT(slotCheckStandard()));
-    slotCheckStandard();
-    connect(m_standard.profiles_list, SIGNAL(itemSelectionChanged()), this, SLOT(slotCheckSelectedItem()));
-
-    // select default profile
-    if (!KdenliveSettings::default_profile().isEmpty()) {
-        for (int i = 0; i < m_standard.profiles_list->count(); ++i) {
-            if (m_standard.profiles_list->item(i)->data(Qt::UserRole).toString() == KdenliveSettings::default_profile()) {
-                m_standard.profiles_list->setCurrentRow(i);
-                m_standard.profiles_list->scrollToItem(m_standard.profiles_list->currentItem());
-                break;
-            }
-        }
-    }
-
-    setPage(2, page2);
-
-    QWizardPage *page3 = new QWizardPage;
-    page3->setTitle(i18n("Additional Settings"));
-    m_extra.setupUi(page3);
-    m_extra.projectfolder->setMode(KFile::Directory);
-    m_extra.projectfolder->setUrl(QUrl(KdenliveSettings::defaultprojectfolder()));
-    m_extra.videothumbs->setChecked(KdenliveSettings::videothumbnails());
-    m_extra.audiothumbs->setChecked(KdenliveSettings::audiothumbnails());
-    m_extra.autosave->setChecked(KdenliveSettings::crashrecovery());
-    connect(m_extra.videothumbs, SIGNAL(stateChanged(int)), this, SLOT(slotCheckThumbs()));
-    connect(m_extra.audiothumbs, SIGNAL(stateChanged(int)), this, SLOT(slotCheckThumbs()));
-    slotCheckThumbs();
-    addPage(page3);*/
-
-#ifndef Q_WS_MAC
-    /*QWizardPage *page6 = new QWizardPage;
-    page6->setTitle(i18n("Capture device"));
-    m_capture.setupUi(page6);
-    bool found_decklink = Render::getBlackMagicDeviceList(m_capture.decklink_devices);
-    KdenliveSettings::setDecklink_device_found(found_decklink);
-    if (found_decklink) m_capture.decklink_status->setText(i18n("Default Blackmagic Decklink card:"));
-    else m_capture.decklink_status->setText(i18n("No Blackmagic Decklink device found"));
-    connect(m_capture.decklink_devices, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateDecklinkDevice(int)));
-    connect(m_capture.button_reload, SIGNAL(clicked()), this, SLOT(slotDetectWebcam()));
-    connect(m_capture.v4l_devices, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateCaptureParameters()));
-    connect(m_capture.v4l_formats, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSaveCaptureFormat()));
-    m_capture.button_reload->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));*/
-
-#endif
-
-    // listViewDelegate = new WizardDelegate(treeWidget);
-    // m_check.programList->setItemDelegate(listViewDelegate);
-    // slotDetectWebcam();
-    // QTimer::singleShot(500, this, SLOT(slotCheckMlt()));
-}
-
-void Wizard::slotDetectWebcam()
-{
-#ifdef USE_V4L
-    m_capture.v4l_devices->blockSignals(true);
-    m_capture.v4l_devices->clear();
-
-    // Video 4 Linux device detection
-    for (int i = 0; i < 10; ++i) {
-        QString path = "/dev/video" + QString::number(i);
-        if (QFile::exists(path)) {
-            QStringList deviceInfo = V4lCaptureHandler::getDeviceName(path.toUtf8().constData());
-            if (!deviceInfo.isEmpty()) {
-                m_capture.v4l_devices->addItem(deviceInfo.at(0), path);
-                m_capture.v4l_devices->setItemData(m_capture.v4l_devices->count() - 1, deviceInfo.at(1), Qt::UserRole + 1);
-            }
-        }
-    }
-    if (m_capture.v4l_devices->count() > 0) {
-        m_capture.v4l_status->setText(i18n("Default video4linux device:"));
-        // select default device
-        bool found = false;
-        for (int i = 0; i < m_capture.v4l_devices->count(); ++i) {
-            QString device = m_capture.v4l_devices->itemData(i).toString();
-            if (device == KdenliveSettings::video4vdevice()) {
-                m_capture.v4l_devices->setCurrentIndex(i);
-                found = true;
-                break;
-            }
-        }
-        slotUpdateCaptureParameters();
-        if (!found) {
-            m_capture.v4l_devices->setCurrentIndex(0);
-        }
-    } else {
-        m_capture.v4l_status->setText(i18n("No device found, plug your webcam and refresh."));
-    }
-    m_capture.v4l_devices->blockSignals(false);
-#endif /* USE_V4L */
-}
-
-void Wizard::slotUpdateCaptureParameters()
-{
-    QString device = m_capture.v4l_devices->itemData(m_capture.v4l_devices->currentIndex()).toString();
-    if (!device.isEmpty()) {
-        KdenliveSettings::setVideo4vdevice(device);
-    }
-
-    QString formats = m_capture.v4l_devices->itemData(m_capture.v4l_devices->currentIndex(), Qt::UserRole + 1).toString();
-
-    m_capture.v4l_formats->blockSignals(true);
-    m_capture.v4l_formats->clear();
-
-    QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/profiles/"));
-    if (!dir.exists()) {
-        dir.mkpath(QStringLiteral("."));
-    }
-
-    if (ProfileRepository::get()->profileExists(dir.absoluteFilePath(QStringLiteral("video4linux")))) {
-        auto &profileInfo = ProfileRepository::get()->getProfile(dir.absoluteFilePath(QStringLiteral("video4linux")));
-        m_capture.v4l_formats->addItem(i18n("Current settings (%1x%2, %3/%4fps)", profileInfo->width(), profileInfo->height(), profileInfo->frame_rate_num(),
-                                            profileInfo->frame_rate_den()),
-                                       QStringList() << QStringLiteral("unknown") << QString::number(profileInfo->width())
-                                                     << QString::number(profileInfo->height()) << QString::number(profileInfo->frame_rate_num())
-                                                     << QString::number(profileInfo->frame_rate_den()));
-    }
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QStringList pixelformats = formats.split('>', QString::SkipEmptyParts);
-#else
-    QStringList pixelformats = formats.split('>', Qt::SkipEmptyParts);
-#endif
-    QString itemSize;
-    QString pixelFormat;
-    QStringList itemRates;
-    for (int i = 0; i < pixelformats.count(); ++i) {
-        QString format = pixelformats.at(i).section(QLatin1Char(':'), 0, 0);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        QStringList sizes = pixelformats.at(i).split(':', QString::SkipEmptyParts);
-#else
-        QStringList sizes = pixelformats.at(i).split(':', Qt::SkipEmptyParts);
-#endif
-        pixelFormat = sizes.takeFirst();
-        for (int j = 0; j < sizes.count(); ++j) {
-            itemSize = sizes.at(j).section(QLatin1Char('='), 0, 0);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            itemRates = sizes.at(j).section(QLatin1Char('='), 1, 1).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
-            itemRates = sizes.at(j).section(QLatin1Char('='), 1, 1).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
-            for (int k = 0; k < itemRates.count(); ++k) {
-                QString formatDescription =
-                    QLatin1Char('[') + format + QStringLiteral("] ") + itemSize + QStringLiteral(" (") + itemRates.at(k) + QLatin1Char(')');
-                if (m_capture.v4l_formats->findText(formatDescription) == -1) {
-                    m_capture.v4l_formats->addItem(formatDescription, QStringList() << format << itemSize.section('x', 0, 0) << itemSize.section('x', 1, 1)
-                                                                                    << itemRates.at(k).section(QLatin1Char('/'), 0, 0)
-                                                                                    << itemRates.at(k).section(QLatin1Char('/'), 1, 1));
-                }
-            }
-        }
-    }
-    if (!dir.exists(QStringLiteral("video4linux"))) {
-        if (m_capture.v4l_formats->count() > 9) {
-            slotSaveCaptureFormat();
-        } else {
-            // No existing profile and no autodetected profiles
-            std::unique_ptr<ProfileParam> profileInfo(new ProfileParam(pCore->getCurrentProfile().get()));
-            profileInfo->m_width = 320;
-            profileInfo->m_height = 200;
-            profileInfo->m_frame_rate_num = 15;
-            profileInfo->m_frame_rate_den = 1;
-            profileInfo->m_display_aspect_num = 4;
-            profileInfo->m_display_aspect_den = 3;
-            profileInfo->m_sample_aspect_num = 1;
-            profileInfo->m_sample_aspect_den = 1;
-            profileInfo->m_progressive = true;
-            profileInfo->m_colorspace = 601;
-            ProfileRepository::get()->saveProfile(profileInfo.get(), dir.absoluteFilePath(QStringLiteral("video4linux")));
-            m_capture.v4l_formats->addItem(i18n("Default settings (%1x%2, %3/%4fps)", profileInfo->width(), profileInfo->height(),
-                                                profileInfo->frame_rate_num(), profileInfo->frame_rate_den()),
-                                           QStringList()
-                                               << QStringLiteral("unknown") << QString::number(profileInfo->width()) << QString::number(profileInfo->height())
-                                               << QString::number(profileInfo->frame_rate_num()) << QString::number(profileInfo->frame_rate_den()));
-        }
-    }
-    m_capture.v4l_formats->blockSignals(false);
 }
 
 void Wizard::checkMltComponents()
@@ -388,8 +195,8 @@ void Wizard::checkMltComponents()
         int mltVersion = QT_VERSION_CHECK(MLT_MIN_MAJOR_VERSION, MLT_MIN_MINOR_VERSION, MLT_MIN_PATCH_VERSION);
         int runningVersion = mlt_version_get_int();
         if (runningVersion < mltVersion) {
-            m_errors.append(
-                i18n("<li>Unsupported MLT version<br/>Please <b>upgrade</b> to %1.%2.%3</li>", MLT_MIN_MAJOR_VERSION, MLT_MIN_MINOR_VERSION, MLT_MIN_PATCH_VERSION));
+            m_errors.append(i18n("<li>Unsupported MLT version<br/>Please <b>upgrade</b> to %1.%2.%3</li>", MLT_MIN_MAJOR_VERSION, MLT_MIN_MINOR_VERSION,
+                                 MLT_MIN_PATCH_VERSION));
             m_systemCheckIsOk = false;
         }
         // Retrieve the list of available transitions.
@@ -430,8 +237,7 @@ void Wizard::checkMltComponents()
         if (!hasAvfilter) {
             // AVFilter effects not found
             qDebug() << "Missing AVFilter module";
-            m_warnings.append(
-                i18n("<li>Missing package: <b>AVFilter</b><br/>provides many effects. Install recommended</li>"));
+            m_warnings.append(i18n("<li>Missing package: <b>AVFilter</b><br/>provides many effects. Install recommended</li>"));
         } else {
             // Check that we have the avfilter.subtitles effects installed
             bool hasSubtitle = false;
@@ -445,14 +251,12 @@ void Wizard::checkMltComponents()
             if (!hasSubtitle) {
                 // avfilter.subtitles effect not found
                 qDebug() << "Missing avfilter.subtitles module";
-                m_warnings.append(
-                    i18n("<li>Missing filter: <b>avfilter.subtitles</b><br/>required for subtitle feature. Install recommended</li>"));
+                m_warnings.append(i18n("<li>Missing filter: <b>avfilter.subtitles</b><br/>required for subtitle feature. Install recommended</li>"));
             }
         }
         delete filters;
 
-
-#if(!(defined(Q_OS_WIN)||defined(Q_OS_MAC)))
+#if (!(defined(Q_OS_WIN) || defined(Q_OS_MAC)))
         // Check that we have the breeze icon theme installed
         const QStringList iconPaths = QIcon::themeSearchPaths();
         bool hasBreeze = false;
@@ -535,10 +339,13 @@ void Wizard::checkMltComponents()
         if (!producersItemList.contains(QStringLiteral("kdenlivetitle"))) {
             qDebug() << "Missing TITLER MLT module";
             m_warnings.append(i18n("<li>Missing MLT module: <b>kdenlivetitle</b><br/>required to create titles</li>"));
-            KdenliveSettings::setHastitleproducer(false);
             m_brokenModule = true;
-        } else {
-            KdenliveSettings::setHastitleproducer(true);
+        }
+        // Animation module
+        if (!producersItemList.contains(QStringLiteral("glaxnimate"))) {
+            qDebug() << "Missing Glaxnimate MLT module";
+            m_warnings.append(i18n("<li>Missing MLT module: <b>glaxnimate</b><br/>required to load Lottie animations</li>"));
+            m_brokenModule = true;
         }
     }
     if (m_systemCheckIsOk && !m_brokenModule) {
@@ -565,7 +372,7 @@ void Wizard::slotCheckPrograms(QString &infos, QString &warnings)
         if (exepath.isEmpty()) {
             exepath = QStandardPaths::findExecutable(QString("ffmpeg%1").arg(FFMPEG_SUFFIX));
         }
-        qDebug() << "Found FFMpeg binary: "<<exepath;
+        qDebug() << "Found FFMpeg binary: " << exepath;
         if (exepath.isEmpty()) {
             // Check for libav version
             exepath = QStandardPaths::findExecutable(QStringLiteral("avconv"));
@@ -613,45 +420,50 @@ void Wizard::slotCheckPrograms(QString &infos, QString &warnings)
         KdenliveSettings::setFfprobepath(probepath);
     }
 
-    // Deprecated
-    /*
-    #ifndef Q_WS_MAC
-        item = new QTreeWidgetItem(m_treeWidget, QStringList() << QString() << i18n("dvgrab"));
-        item->setData(1, Qt::UserRole, i18n("Required for firewire capture"));
-        item->setSizeHint(0, m_itemSize);
-        if (QStandardPaths::findExecutable(QStringLiteral("dvgrab")).isEmpty()) item->setIcon(0, m_badIcon);
-        else item->setIcon(0, m_okIcon);
-    #endif
-    */
-
     // set up some default applications
     QString program;
     if (KdenliveSettings::defaultimageapp().isEmpty()) {
-        program = QStandardPaths::findExecutable(QStringLiteral("gimp"));
-        if (program.isEmpty()) {
-            program = QStandardPaths::findExecutable(QStringLiteral("krita"));
+        QString imageBinary = QStandardPaths::findExecutable(QStringLiteral("gimp"));
+#ifdef Q_OS_WIN
+        if (imageBinary.isEmpty()) {
+            imageBinary = QStandardPaths::findExecutable(QStringLiteral("gimp"), {"C:/Program Files/Gimp", "C:/Program Files (x86)/Gimp"});
         }
-        if (!program.isEmpty()) {
-            KdenliveSettings::setDefaultimageapp(program);
+#endif
+        if (imageBinary.isEmpty()) {
+            imageBinary = QStandardPaths::findExecutable(QStringLiteral("krita"));
+        }
+#ifdef Q_OS_WIN
+        if (imageBinary.isEmpty()) {
+            imageBinary = QStandardPaths::findExecutable(QStringLiteral("krita"), {"C:/Program Files/Krita", "C:/Program Files (x86)/Krita"});
+        }
+#endif
+        if (!imageBinary.isEmpty()) {
+            KdenliveSettings::setDefaultimageapp(imageBinary);
         }
     }
     if (KdenliveSettings::defaultaudioapp().isEmpty()) {
-        program = QStandardPaths::findExecutable(QStringLiteral("audacity"));
-        if (program.isEmpty()) {
-            program = QStandardPaths::findExecutable(QStringLiteral("traverso"));
+        QString audioBinary = QStandardPaths::findExecutable(QStringLiteral("audacity"));
+#ifdef Q_OS_WIN
+        if (audioBinary.isEmpty()) {
+            audioBinary = QStandardPaths::findExecutable(QStringLiteral("audacity"), {"C:/Program Files/Audacity", "C:/Program Files (x86)/Audacity"});
         }
-        if (!program.isEmpty()) {
-            KdenliveSettings::setDefaultaudioapp(program);
+#endif
+        if (audioBinary.isEmpty()) {
+            audioBinary = QStandardPaths::findExecutable(QStringLiteral("traverso"));
+        }
+        if (!audioBinary.isEmpty()) {
+            KdenliveSettings::setDefaultaudioapp(audioBinary);
         }
     }
-
-    if (KdenliveSettings::defaultaudioapp().isEmpty()) {
-        program = QStandardPaths::findExecutable(QStringLiteral("audacity"));
-        if (program.isEmpty()) {
-            program = QStandardPaths::findExecutable(QStringLiteral("traverso"));
+    if (KdenliveSettings::glaxnimatePath().isEmpty()) {
+        QString animBinary = QStandardPaths::findExecutable(QStringLiteral("glaxnimate"));
+#ifdef Q_OS_WIN
+        if (animBinary.isEmpty()) {
+            animBinary = QStandardPaths::findExecutable(QStringLiteral("glaxnimate"), {"C:/Program Files/Glaxnimate", "C:/Program Files (x86)/Glaxnimate"});
         }
-        if (!program.isEmpty()) {
-            KdenliveSettings::setDefaultaudioapp(program);
+#endif
+        if (!animBinary.isEmpty()) {
+            KdenliveSettings::setGlaxnimatePath(animBinary);
         }
     }
 
@@ -751,83 +563,17 @@ void Wizard::runUpdateMimeDatabase()
     }
 }
 
-void Wizard::slotCheckStandard()
-{
-    m_standard.profiles_list->clear();
-    QStringList profiles;
-    if (!m_standard.button_hdv->isChecked()) {
-        // DV standard
-        QMapIterator<QString, QString> i(m_dvProfiles);
-        while (i.hasNext()) {
-            i.next();
-            auto *item = new QListWidgetItem(i.key(), m_standard.profiles_list);
-            item->setData(Qt::UserRole, i.value());
-        }
-    }
-    if (!m_standard.button_dv->isChecked()) {
-        // HDV standard
-        QMapIterator<QString, QString> i(m_hdvProfiles);
-        while (i.hasNext()) {
-            i.next();
-            auto *item = new QListWidgetItem(i.key(), m_standard.profiles_list);
-            item->setData(Qt::UserRole, i.value());
-        }
-    }
-    if (m_standard.button_all->isChecked()) {
-        QMapIterator<QString, QString> i(m_otherProfiles);
-        while (i.hasNext()) {
-            i.next();
-            auto *item = new QListWidgetItem(i.key(), m_standard.profiles_list);
-            item->setData(Qt::UserRole, i.value());
-        }
-        // m_standard.profiles_list->sortItems();
-    }
-
-    for (int i = 0; i < m_standard.profiles_list->count(); ++i) {
-        QListWidgetItem *item = m_standard.profiles_list->item(i);
-
-        std::unique_ptr<ProfileModel> &curProfile = ProfileRepository::get()->getProfile(item->data(Qt::UserRole).toString());
-        const QString infoString =
-            QStringLiteral("<strong>") + i18n("Frame size:") +
-            QStringLiteral(" </strong>%1x%2<br /><strong>").arg(curProfile->width()).arg(curProfile->height()) + i18n("Frame rate:") +
-            QStringLiteral(" </strong>%1/%2<br /><strong>").arg(curProfile->frame_rate_num()).arg(curProfile->frame_rate_den()) + i18n("Pixel aspect ratio:") +
-            QStringLiteral("</strong>%1/%2<br /><strong>").arg(curProfile->sample_aspect_num()).arg(curProfile->sample_aspect_den()) +
-            i18n("Display aspect ratio:") + QStringLiteral(" </strong>%1/%2").arg(curProfile->display_aspect_num()).arg(curProfile->display_aspect_den());
-
-        /*const QString infoString = QStringLiteral("<strong>" + i18n("Frame size:") + QStringLiteral(" </strong>%1x%2<br /><strong>") + i18n("Frame rate:") +
-                                    QStringLiteral(" </strong>%3/%4<br /><strong>") + i18n("Pixel aspect ratio:") +
-                                    QStringLiteral("</strong>%5/%6<br /><strong>") + i18n("Display aspect ratio:") + QStringLiteral(" </strong>%7/%8"))
-                                       .arg(QString::number(curProfile->width()), QString::number(curProfile->height()),
-                                            QString::number(curProfile->frame_rate_num()), QString::number(curProfile->frame_rate_den()),
-                                            QString::number(curProfile->sample_aspect_num()), QString::number(curProfile->sample_aspect_den()),
-                                            QString::number(curProfile->display_aspect_num()), QString::number(curProfile->display_aspect_den()));*/
-        item->setToolTip(infoString);
-    }
-
-    m_standard.profiles_list->setSortingEnabled(true);
-    m_standard.profiles_list->setCurrentRow(0);
-}
-
-void Wizard::slotCheckSelectedItem()
-{
-    // Make sure we always have an item highlighted
-    m_standard.profiles_list->setCurrentRow(m_standard.profiles_list->currentRow());
-}
-
 void Wizard::adjustSettings()
 {
-    // if (m_extra.installmimes->isChecked()) {
-    {
-        QStringList globs;
+    QStringList globs;
 
-        globs << QStringLiteral("*.mts") << QStringLiteral("*.m2t") << QStringLiteral("*.mod") << QStringLiteral("*.ts") << QStringLiteral("*.m2ts")
-              << QStringLiteral("*.m2v");
-        installExtraMimes(QStringLiteral("video/mpeg"), globs);
-        globs.clear();
-        globs << QStringLiteral("*.dv");
-        installExtraMimes(QStringLiteral("video/dv"), globs);
-        runUpdateMimeDatabase();
-    }
+    globs << QStringLiteral("*.mts") << QStringLiteral("*.m2t") << QStringLiteral("*.mod") << QStringLiteral("*.ts") << QStringLiteral("*.m2ts")
+          << QStringLiteral("*.m2v");
+    installExtraMimes(QStringLiteral("video/mpeg"), globs);
+    globs.clear();
+    globs << QStringLiteral("*.dv");
+    installExtraMimes(QStringLiteral("video/dv"), globs);
+    runUpdateMimeDatabase();
 }
 
 void Wizard::slotCheckMlt()
@@ -865,46 +611,16 @@ bool Wizard::isOk() const
 
 void Wizard::slotOpenManual()
 {
-#if KIO_VERSION >= QT_VERSION_CHECK(5,71,0)
     auto *job = new KIO::OpenUrlJob(QUrl(QStringLiteral("https://docs.kdenlive.org/troubleshooting/installation_troubleshooting.html")));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#else
     job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#endif
     // methods like setRunExecutables, setSuggestedFilename, setEnableExternalBrowser, setFollowRedirections
     // exist in both classes
     job->start();
     //KIO::OpenUrlJob(QUrl(QStringLiteral("https://docs.kdenlive.org/troubleshooting/installation_troubleshooting.html")), QStringLiteral("text/html"));
-#else
-    KRun::runUrl(QUrl(QStringLiteral("https://docs.kdenlive.org/troubleshooting/installation_troubleshooting.html")), QStringLiteral("text/html"), this, KRun::RunFlags());
-#endif
-}
-
-void Wizard::slotSaveCaptureFormat()
-{
-    QStringList format = m_capture.v4l_formats->itemData(m_capture.v4l_formats->currentIndex()).toStringList();
-    if (format.isEmpty()) {
-        return;
-    }
-    std::unique_ptr<ProfileParam> profile(new ProfileParam(pCore->getCurrentProfile().get()));
-    profile->m_description = QStringLiteral("Video4Linux Capture");
-    profile->m_colorspace = 601;
-    profile->m_width = format.at(1).toInt();
-    profile->m_height = format.at(2).toInt();
-    profile->m_sample_aspect_num = 1;
-    profile->m_sample_aspect_den = 1;
-    profile->m_display_aspect_num = format.at(1).toInt();
-    profile->m_display_aspect_den = format.at(2).toInt();
-    profile->m_frame_rate_num = format.at(3).toInt();
-    profile->m_frame_rate_den = format.at(4).toInt();
-    profile->m_progressive = true;
-    QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/profiles/"));
-    if (!dir.exists()) {
-        dir.mkpath(QStringLiteral("."));
-    }
-    ProfileRepository::get()->saveProfile(profile.get(), dir.absoluteFilePath(QStringLiteral("video4linux")));
-}
-
-void Wizard::slotUpdateDecklinkDevice(uint captureCard)
-{
-    KdenliveSettings::setDecklink_capturedevice(captureCard);
 }
 
 void Wizard::testHwEncoders()
@@ -919,7 +635,8 @@ void Wizard::testHwEncoders()
     tmp.close();
 
     // VAAPI testing
-    QStringList args{"-hide_banner", "-y",
+    QStringList args{"-hide_banner",
+                     "-y",
                      "-vaapi_device",
                      "/dev/dri/renderD128",
                      "-f",
@@ -954,24 +671,25 @@ void Wizard::testHwEncoders()
     KdenliveSettings::setVaapiEnabled(vaapiSupported);
 
     // VAAPI with scaling support
-    QStringList scaleargs{"-hide_banner", "-y"
-                     ,"-hwaccel"
-                     ,"vaapi"
-                     ,"-hwaccel_output_format"
-                     ,"vaapi"
-                     ,"/dev/dri/renderD128"
-                     ,"-f"
-                     ,"lavfi"
-                     ,"-i"
-                     ,"smptebars=duration=5:size=1280x720:rate=25"
-                     ,"-vf"
-                     ,"scale_vaapi=w=640:h=-2:format=nv12,hwupload"
-                     ,"-c:v"
-                     ,"h264_vaapi"
-                     ,"-an"
-                     ,"-f"
-                     ,"mp4"
-                     ,tmp.fileName()};
+    QStringList scaleargs{"-hide_banner",
+                          "-y",
+                          "-hwaccel",
+                          "vaapi",
+                          "-hwaccel_output_format",
+                          "vaapi",
+                          "/dev/dri/renderD128",
+                          "-f",
+                          "lavfi",
+                          "-i",
+                          "smptebars=duration=5:size=1280x720:rate=25",
+                          "-vf",
+                          "scale_vaapi=w=640:h=-2:format=nv12,hwupload",
+                          "-c:v",
+                          "h264_vaapi",
+                          "-an",
+                          "-f",
+                          "mp4",
+                          tmp.fileName()};
     qDebug() << "// FFMPEG ARGS: " << scaleargs;
     hwEncoders.start(KdenliveSettings::ffmpegpath(), scaleargs);
     bool vaapiScalingSupported = false;
@@ -997,9 +715,8 @@ void Wizard::testHwEncoders()
         return;
     }
     tmp2.close();
-    QStringList args2{"-hide_banner", "-y",   "-hwaccel",   "cuvid", "-f", "lavfi", "-i",
-                      "smptebars=duration=5:size=1280x720:rate=25",
-                      "-c:v", "h264_nvenc", "-an",   "-f", "mp4",   tmp2.fileName()};
+    QStringList args2{"-hide_banner", "-y",         "-hwaccel", "cuvid", "-f",  "lavfi",        "-i", "smptebars=duration=5:size=1280x720:rate=25",
+                      "-c:v",         "h264_nvenc", "-an",      "-f",    "mp4", tmp2.fileName()};
     qDebug() << "// FFMPEG ARGS: " << args2;
     hwEncoders.start(KdenliveSettings::ffmpegpath(), args2);
     bool nvencSupported = false;
@@ -1020,7 +737,7 @@ void Wizard::testHwEncoders()
     KdenliveSettings::setNvencEnabled(nvencSupported);
 
     // Testing NVIDIA SCALER
-    QStringList args3{"-hide_banner",   "-filters"};
+    QStringList args3{"-hide_banner", "-filters"};
     qDebug() << "// FFMPEG ARGS: " << args3;
     hwEncoders.start(KdenliveSettings::ffmpegpath(), args3);
     bool nvScalingSupported = false;
