@@ -174,7 +174,7 @@ bool DocumentChecker::hasErrorInClips()
             filePath.prepend(root);
         }
         if (!QFile::exists(filePath)) {
-            QString lumaName = filePath.section(QLatin1Char('/'), -1);
+            QString lumaName = QFileInfo(filePath).fileName();
             // MLT 7 now generates lumas on the fly for files named luma01.pgm to luma22.pgm, so don't detect these as missing
             if (lumaName.length() == 10 && lumaName.startsWith(QLatin1String("luma")) && lumaName.endsWith(QLatin1String(".pgm"))) {
                 bool ok;
@@ -197,28 +197,9 @@ bool DocumentChecker::hasErrorInClips()
                 continue;
             }
             // Check Kdenlive folder
-            if (lumaPath.isEmpty()) {
-                QDir dir(QCoreApplication::applicationDirPath());
-                dir.cdUp();
-                dir.cd(QStringLiteral("share/kdenlive/lumas/"));
-                lumaPath = dir.absolutePath() + QStringLiteral("/");
-            }
-            lumaName = filePath.section(QLatin1Char('/'), -2);
-            lumaName.prepend(lumaPath);
-            if (QFile::exists(lumaName)) {
-                autoFixLuma.insert(filePath, lumaName);
-                continue;
-            }
-            // Check MLT folder
-            if (lumaMltPath.isEmpty()) {
-                QDir dir(KdenliveSettings::mltpath());
-                dir.cd(QStringLiteral("../lumas/"));
-                lumaMltPath = dir.absolutePath() + QStringLiteral("/");
-            }
-            lumaName = filePath.section(QLatin1Char('/'), -2);
-            lumaName.prepend(lumaMltPath);
-            if (QFile::exists(lumaName)) {
-                autoFixLuma.insert(filePath, lumaName);
+            QString res = fixLuma(filePath);
+            if (!res.isEmpty() && QFile::exists(res)) {
+                autoFixLuma.insert(filePath, res);
                 continue;
             }
 
@@ -383,12 +364,24 @@ bool DocumentChecker::hasErrorInClips()
             item->setData(0, hashRole, Xml::getXmlProperty(e, QStringLiteral("kdenlive:file_hash")));
             item->setData(0, sizeRole, Xml::getXmlProperty(e, QStringLiteral("kdenlive:file_size")));
             if (!m_rootReplacement.first.isEmpty()) {
-                const QString relocated = relocateResource(resource);
+                QString relocated;
+                if (type == ClipType::SlideShow) {
+                    // Strip filename
+                    relocated = QFileInfo(resource).absolutePath();
+                } else {
+                    relocated = resource;
+                }
+
+                relocated = relocateResource(relocated);
                 if (!relocated.isEmpty()) {
                     item->setIcon(0, QIcon::fromTheme(QStringLiteral("dialog-ok")));
                     item->setData(0, statusRole, CLIPOK);
                     item->setToolTip(0, i18n("Relocated item"));
-                    resource = relocated;
+                    if (type == ClipType::SlideShow) {
+                        resource = QDir(relocated).absoluteFilePath(QFileInfo(resource).fileName());
+                    } else {
+                        resource = relocated;
+                    }
                 }
             }
             item->setText(1, resource);
@@ -610,7 +603,8 @@ const QString DocumentChecker::relocateResource(QString sourceResource)
 {
     if (sourceResource.startsWith(m_rootReplacement.first)) {
         sourceResource.replace(m_rootReplacement.first, m_rootReplacement.second);
-        if (QFile::exists(sourceResource)) {
+        // Use QFileInfo to ensure we also handle directories (for slideshows)
+        if (QFileInfo::exists(sourceResource)) {
             return sourceResource;
         }
         return QString();
@@ -622,7 +616,7 @@ const QString DocumentChecker::relocateResource(QString sourceResource)
     // Find common ancestor
     int ix = 0;
     for (auto &cut : cutRoot) {
-        if (ix < cutResource.size()) {
+        if (!cutResource.isEmpty()) {
             if (cutResource.first() != cut) {
                 break;
             }
@@ -643,7 +637,8 @@ const QString DocumentChecker::relocateResource(QString sourceResource)
     basePath.append(QLatin1Char('/'));
     basePath.append(cutResource.join(QLatin1Char('/')));
     qDebug() << "/// RESULTING PATH: " << basePath;
-    if (QFile::exists(basePath)) {
+    // Use QFileInfo to ensure we also handle directories (for slideshows)
+    if (QFileInfo::exists(basePath)) {
         return basePath;
     }
     return QString();
@@ -769,6 +764,7 @@ QString DocumentChecker::getMissingProducers(const QDomElement &e, const QDomNod
         if (QFileInfo(original).isRelative()) {
             original.prepend(root);
         }
+
         // Check for slideshows
         bool slideshow = original.contains(QStringLiteral("/.all.")) || original.contains(QStringLiteral("\\.all.")) || original.contains(QLatin1Char('?')) ||
                          original.contains(QLatin1Char('%'));
@@ -776,9 +772,28 @@ QString DocumentChecker::getMissingProducers(const QDomElement &e, const QDomNod
             original = QFileInfo(original).absolutePath();
         }
         if (!QFile::exists(original)) {
+            bool resourceFixed = false;
+            if (!m_rootReplacement.first.isEmpty()) {
+                QString movedOriginal = relocateResource(original);
+                if (!movedOriginal.isEmpty()) {
+                    if (slideshow) {
+                        movedOriginal = QDir(movedOriginal).absoluteFilePath(QFileInfo(original).fileName());
+                    }
+                    Xml::setXmlProperty(e, QStringLiteral("kdenlive:originalurl"), movedOriginal);
+                    if (!QFile::exists(producerResource)) {
+                        Xml::setXmlProperty(e, QStringLiteral("resource"), movedOriginal);
+                    }
+                    resourceFixed = true;
+                    if (proxyFound) {
+                        return QString();
+                    }
+                }
+            }
             if (!proxyFound) {
                 // Neither proxy nor original file found
-                m_missingClips.append(e);
+                if (!resourceFixed) {
+                    m_missingClips.append(e);
+                }
                 m_missingProxies.append(e);
             } else {
                 // clip has proxy but original clip is missing
@@ -1007,10 +1022,10 @@ void DocumentChecker::slotSearchClips(const QString &newpath)
     m_checkRunning = false;
 }
 
-QString DocumentChecker::searchLuma(const QDir &dir, const QString &file)
+QString DocumentChecker::fixLuma(const QString &file)
 {
     QDir searchPath(KdenliveSettings::mltpath());
-    QString fname = QUrl::fromLocalFile(file).fileName();
+    QString fname = QFileInfo(file).fileName();
     if (file.contains(QStringLiteral("PAL"))) {
         searchPath.cd(QStringLiteral("../lumas/PAL"));
     } else {
@@ -1023,21 +1038,41 @@ QString DocumentChecker::searchLuma(const QDir &dir, const QString &file)
     // try to find luma in application path
     searchPath.setPath(QCoreApplication::applicationDirPath());
 #ifdef Q_OS_WIN
-    searchPath.cd(QStringLiteral("data/lumas"));
+    searchPath.cd(QStringLiteral("data/"));
 #else
-    searchPath.cd(QStringLiteral("../share/apps/kdenlive/lumas"));
+    searchPath.cd(QStringLiteral("../share/kdenlive/"));
 #endif
+    if (file.contains(QStringLiteral("/PAL"))) {
+        searchPath.cd(QStringLiteral("lumas/PAL/"));
+    } else {
+        searchPath.cd(QStringLiteral("lumas/HD/"));
+    }
     result.setFile(searchPath, fname);
     if (result.exists()) {
         return result.filePath();
     }
     // Try in Kdenlive's standard KDE path
-    QString res = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("lumas/") + fname);
+    QString res = QStandardPaths::locate(QStandardPaths::AppDataLocation, "lumas", QStandardPaths::LocateDirectory);
     if (!res.isEmpty()) {
-        return res;
+        searchPath.setPath(res);
+        if (file.contains(QStringLiteral("/PAL"))) {
+            searchPath.cd(QStringLiteral("PAL"));
+        } else {
+            searchPath.cd(QStringLiteral("HD"));
+        }
+        result.setFile(searchPath, fname);
+        if (result.exists()) {
+            return result.filePath();
+        }
     }
+    return QString();
+}
+
+QString DocumentChecker::searchLuma(const QDir &dir, const QString &file)
+{
     // Try in user's chosen folder
-    return searchPathRecursively(dir, fname);
+    QString result = fixLuma(file);
+    return result.isEmpty() ? searchPathRecursively(dir, QFileInfo(file).fileName()) : result;
 }
 
 QString DocumentChecker::searchPathRecursively(const QDir &dir, const QString &fileName, ClipType::ProducerType type)
@@ -1353,7 +1388,6 @@ void DocumentChecker::fixSourceClipItem(QTreeWidgetItem *child, const QDomNodeLi
 {
     QDomElement e, property;
     QDomNodeList properties;
-    // int t = child->data(0, typeRole).toInt();
     if (child->data(0, statusRole).toInt() == CLIPOK) {
         QString id = child->data(0, idRole).toString();
         for (int i = 0; i < producers.count(); ++i) {
