@@ -30,6 +30,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include <config-kdenlive.h>
 
+#include "utils/KMessageBox_KdenliveCompat.h"
 #include <KBookmark>
 #include <KBookmarkManager>
 #include <KIO/CopyJob>
@@ -366,22 +367,23 @@ void KdenliveDoc::initializeProperties(bool newDocument)
     m_documentProperties[QStringLiteral("seekOffset")] = QString::number(TimelineModel::seekDuration);
     if (newDocument) {
         // For existing documents, don't define guidesCategories, so that we can use the getDefaultGuideCategories() for backwards compatibility
-        m_documentProperties[QStringLiteral("guidesCategories")] = KdenliveSettings::guidesCategories().join(QLatin1Char('\n'));
+        m_documentProperties[QStringLiteral("guidesCategories")] = m_guideModel->categoriesListToJSon(KdenliveSettings::guidesCategories());
     }
 }
 
 const QStringList KdenliveDoc::guidesCategories()
 {
     if (!m_documentProperties.contains(QStringLiteral("guidesCategories")) || m_documentProperties.value(QStringLiteral("guidesCategories")).isEmpty()) {
-        const QString defaultCategories = getDefaultGuideCategories().join(QLatin1Char('\n'));
-        m_documentProperties[QStringLiteral("guidesCategories")] = defaultCategories;
+        const QStringList defaultCategories = getDefaultGuideCategories();
+        m_documentProperties[QStringLiteral("guidesCategories")] = m_guideModel->categoriesListToJSon(defaultCategories);
+        return defaultCategories;
     }
-    return m_documentProperties.value(QStringLiteral("guidesCategories")).split(QLatin1Char('\n'));
+    return m_guideModel->guideCategoriesToStringList(m_documentProperties.value(QStringLiteral("guidesCategories")));
 }
 
 void KdenliveDoc::updateGuideCategories(const QStringList &categories, const QMap<int, int> remapCategories)
 {
-    const QStringList currentCategories = m_documentProperties.value(QStringLiteral("guidesCategories")).split(QLatin1Char('\n'));
+    const QStringList currentCategories = m_guideModel->guideCategoriesToStringList(m_documentProperties.value(QStringLiteral("guidesCategories")));
     // Check if a guide category was removed
     QList<int> currentIndexes;
     QList<int> updatedIndexes;
@@ -403,8 +405,8 @@ void KdenliveDoc::updateGuideCategories(const QStringList &categories, const QMa
 
 void KdenliveDoc::saveGuideCategories()
 {
-    const QStringList categories = m_guideModel->categoriesToStringList();
-    m_documentProperties[QStringLiteral("guidesCategories")] = categories.join(QLatin1Char('\n'));
+    const QString categories = m_guideModel->categoriesToJSon();
+    m_documentProperties[QStringLiteral("guidesCategories")] = categories;
 }
 
 int KdenliveDoc::updateClipsCount()
@@ -1630,7 +1632,7 @@ void KdenliveDoc::switchProfile(ProfileParam *pf, const QString &clipName)
         if (KdenliveSettings::default_profile().isEmpty()) {
             // Default project format not yet confirmed, propose
             QString currentProfileDesc = pCore->getCurrentProfile()->description();
-            KMessageBox::ButtonCode answer = KMessageBox::questionYesNoCancel(
+            KMessageBox::ButtonCode answer = KMessageBox::questionTwoActionsCancel(
                 QApplication::activeWindow(),
                 i18n("Your default project profile is %1, but your clip's profile (%2) is %3.\nDo you want to change default profile for future projects?",
                      currentProfileDesc, clipName, profile->description()),
