@@ -35,6 +35,7 @@ class MarkerListModel;
 class Render;
 class ProfileParam;
 class SubtitleModel;
+class MarkerSortModel;
 
 class QUndoGroup;
 class QUndoCommand;
@@ -93,6 +94,8 @@ public:
     /** @brief Open an existing Kdenlive project, returning nothing if the project cannot be opened. */
     static DocOpenResult Open(const QUrl &url, const QString &projectFolder, QUndoGroup *undoGroup,
                 bool recoverCorruption, MainWindow *parent = nullptr);
+    /** @brief Create a dummy project, used for testing. */
+    KdenliveDoc(MainWindow *parent = nullptr);
     ~KdenliveDoc() override;
     friend class LoadJob;
     /** @brief Get current document's producer. */
@@ -127,7 +130,7 @@ public:
     /** @brief Returns the project folder, used to store project temporary files. */
     QString projectTempFolder() const;
     /** @brief Returns the folder used to store project data files (titles, etc). */
-    QString projectDataFolder(const QString &newPath = QString()) const;
+    QString projectDataFolder(const QString &newPath = QString(), bool folderForAudio = false) const;
     void setZoom(int horizontal, int vertical = -1);
     QPoint zoom() const;
     double dar() const;
@@ -160,7 +163,13 @@ public:
     QMap<QString, QString> documentProperties();
     bool useProxy() const;
     bool useExternalProxy() const;
+    /** @brief Returns true if a proxy clip should be automatically generated for this width.
+     *  if width < 0, returns true if the document's automatic proxy generation is enabled
+     */
     bool autoGenerateProxy(int width) const;
+    /** @brief Returns true if a proxy clip should be automatically generated for this width.
+     *  if width < 0, returns true if the document's automatic proxy generation is enabled
+     */
     bool autoGenerateImageProxy(int width) const;
     /** @brief Saves effects embedded in project file. */
     void saveCustomEffects(const QDomNodeList &customeffects);
@@ -187,6 +196,7 @@ public:
 
     /** @brief Returns a pointer to the guide model */
     std::shared_ptr<MarkerListModel> getGuideModel() const;
+    std::shared_ptr<MarkerSortModel> getFilteredGuideModel() const;
 
     // TODO REFAC: delete */
     Render *renderer();
@@ -205,7 +215,12 @@ public:
     int audioChannels() const;
     /** @brief Ensure we don't have leftover preview chunks (created after last save */
     void cleanupTimelinePreview(const QDateTime &documentDate);
-
+    /** @brief Returns the guides categories for the project in format {name:index:#color} */
+    const QStringList guidesCategories();
+    /** @brief Set the guides categories for the project in format {name:index:#color} */
+    void updateGuideCategories(const QStringList &categories, const QMap<int, int> remapCategories = {});
+    /** @brief Setup a filter to visible guides */
+    void setGuidesFilter(const QList<int> filter);
 
     /**
      * If the document used a decimal point different than “.”, it is stored in this property.
@@ -228,14 +243,18 @@ public:
     bool hasSubtitles() const;
     /** @brief Generate a temporary subtitle file for a zone. */
     void generateRenderSubtitleFile(int in, int out, const QString &subtitleFile);
+    /** @brief Returns the dafult definition  for guide categories.*/
+    static const QStringList getDefaultGuideCategories();
 
 private:
     /** @brief Create a new KdenliveDoc using the provided QDomDocument (an
      * existing project file), used by the Open() named constructor. */
     KdenliveDoc(const QUrl &url, QDomDocument& newDom, QString projectFolder, QUndoGroup *undoGroup,
         MainWindow *parent = nullptr);
-    /** @brief Set document default properties using hard-coded values and KdenliveSettings. */
-    void initializeProperties();
+    /** @brief Set document default properties using hard-coded values and KdenliveSettings.
+     *  @param newDocument true if we are creating a new document, false when opening an existing one
+     */
+    void initializeProperties(bool newDocument = true);
     QDomDocument m_document;
     int m_clipsCount;
     /** @brief MLT's root (base path) that is stripped from urls in saved xml */
@@ -264,6 +283,7 @@ private:
     QList<int> m_undoChunks;
     QMap<QString, QString> m_documentProperties;
     QMap<QString, QString> m_documentMetadata;
+    std::shared_ptr<MarkerSortModel> m_guidesFilterModel;
     std::shared_ptr<MarkerListModel> m_guideModel;
     std::weak_ptr<SubtitleModel> m_subtitleModel;
 
@@ -315,6 +335,8 @@ private slots:
     void guidesChanged();
     /** @brief Display error message on failed move. */
     void slotMoveFinished(KJob *job);
+    /** @brief Save the project guide categories in the document properties. */
+    void saveGuideCategories();
 
 signals:
     void resetProjectList();
