@@ -6,7 +6,7 @@
 #pragma once
 
 #include "assets/assetlist/model/assetfilter.hpp"
-#include "effects/effectsrepository.hpp"
+#include "definitions.h"
 #include <memory>
 
 /** @brief This class is used as a proxy model to filter the effect tree based on given criterion (name, type).
