@@ -72,6 +72,8 @@ public:
     void slotNextKeyframe();
     void slotPreviousKeyframe();
     void addRemoveKeyframe();
+    /** @brief Used to pass a standard action like copy or paste to the effect stack widget */
+    void sendStandardCommand(int command);
 
 public slots:
     void slotSyncEffectsPos(int pos);
