@@ -42,8 +42,8 @@ void ProxyTask::start(const ObjectId &owner, QObject *object, bool force)
 
 void ProxyTask::run()
 {
+    AbstractTaskDone whenFinished(m_owner.second, this);
     if (m_isCanceled || pCore->taskManager.isBlocked()) {
-        pCore->taskManager.taskDone(m_owner.second, this);
         return;
     }
     QMutexLocker lock(&m_runMutex);
@@ -57,7 +57,6 @@ void ProxyTask::run()
     if (binClip->getProducerIntProperty(QStringLiteral("_overwriteproxy")) == 0 && fInfo.exists() && fInfo.size() > 0) {
         // Proxy clip already created
         m_progress = 100;
-        pCore->taskManager.taskDone(m_owner.second, this);
         QMetaObject::invokeMethod(m_object, "updateJobProgress");
         QMetaObject::invokeMethod(binClip.get(), "updateProxyProducer", Qt::QueuedConnection, Q_ARG(QString, dest));
         return;
@@ -192,59 +191,60 @@ void ProxyTask::run()
             QMetaObject::invokeMethod(pCore.get(), "displayBinMessage", Qt::QueuedConnection, Q_ARG(QString, i18n("Cannot load image %1.", source)),
                                       Q_ARG(int, int(KMessageWidget::Warning)));
             m_progress = 100;
-            pCore->taskManager.taskDone(m_owner.second, this);
             QMetaObject::invokeMethod(m_object, "updateJobProgress");
             return;
         }
 
         QImage proxy;
-        // Images are scaled to profile size.
-        // TODO: Make it be configurable?
-        if (i.width() > i.height()) {
-            proxy = i.scaledToWidth(KdenliveSettings::proxyimagesize());
-        } else {
-            proxy = i.scaledToHeight(KdenliveSettings::proxyimagesize());
-        }
-        if (exif > 1) {
-            // Rotate image according to exif data
-            QImage processed;
-            QTransform matrix;
-
-            switch (exif) {
-            case 2:
-                matrix.scale(-1, 1);
-                break;
-            case 3:
-                matrix.rotate(180);
-                break;
-            case 4:
-                matrix.scale(1, -1);
-                break;
-            case 5:
-                matrix.rotate(270);
-                matrix.scale(-1, 1);
-                break;
-            case 6:
-                matrix.rotate(90);
-                break;
-            case 7:
-                matrix.rotate(90);
-                matrix.scale(-1, 1);
-                break;
-            case 8:
-                matrix.rotate(270);
-                break;
+        // Images are scaled to predefined size.
+        int maxSize = qMax(i.width(), i.height());
+        if (KdenliveSettings::proxyimagesize() < maxSize) {
+            if (i.width() > i.height()) {
+                proxy = i.scaledToWidth(KdenliveSettings::proxyimagesize());
+            } else {
+                proxy = i.scaledToHeight(KdenliveSettings::proxyimagesize());
             }
-            processed = proxy.transformed(matrix);
-            processed.save(dest);
+            if (exif > 1) {
+                // Rotate image according to exif data
+                QImage processed;
+                QTransform matrix;
+
+                switch (exif) {
+                case 2:
+                    matrix.scale(-1, 1);
+                    break;
+                case 3:
+                    matrix.rotate(180);
+                    break;
+                case 4:
+                    matrix.scale(1, -1);
+                    break;
+                case 5:
+                    matrix.rotate(270);
+                    matrix.scale(-1, 1);
+                    break;
+                case 6:
+                    matrix.rotate(90);
+                    break;
+                case 7:
+                    matrix.rotate(90);
+                    matrix.scale(-1, 1);
+                    break;
+                case 8:
+                    matrix.rotate(270);
+                    break;
+                }
+                processed = proxy.transformed(matrix);
+                processed.save(dest);
+            } else {
+                proxy.save(dest);
+            }
+            result = true;
         } else {
-            proxy.save(dest);
+            // Image is too small to be proxied
+            m_logDetails = i18n("Clip type does not support proxies");
+            result = false;
         }
-        result = true;
-        m_progress = 100;
-        pCore->taskManager.taskDone(m_owner.second, this);
-        QMetaObject::invokeMethod(m_object, "updateJobProgress");
-        return;
     } else {
         m_isFfmpegJob = true;
         if (!QFileInfo(KdenliveSettings::ffmpegpath()).isFile()) {
@@ -254,7 +254,6 @@ void ProxyTask::run()
                                       Q_ARG(int, int(KMessageWidget::Warning)));
             result = true;
             m_progress = 100;
-            pCore->taskManager.taskDone(m_owner.second, this);
             QMetaObject::invokeMethod(m_object, "updateJobProgress");
             return;
         }
@@ -370,7 +369,6 @@ void ProxyTask::run()
                                       Q_ARG(int, int(KMessageWidget::Warning)), Q_ARG(QString, m_logDetails));
         }
     }
-    pCore->taskManager.taskDone(m_owner.second, this);
     QMetaObject::invokeMethod(m_object, "updateJobProgress");
     return;
 }
