@@ -4,8 +4,7 @@
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef TRANSCODETASK_H
-#define TRANSCODETASK_H
+#pragma once
 
 #include "abstracttask.h"
 
@@ -37,6 +36,3 @@ private:
     QString m_errorMessage;
     QString m_logDetails;
 };
-
-
-#endif
