@@ -11,13 +11,12 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "bin/projectclip.h"
 #include "core.h"
 #include "kdenlive_debug.h"
-#include <QImage>
-#include <QElapsedTimer>
-#include <QtConcurrent>
 #include <KLocalizedString>
+#include <QElapsedTimer>
+#include <QImage>
+#include <QtConcurrent>
 #include <algorithm>
 #include <cmath>
-#include <memory>
 
 AudioEnvelope::AudioEnvelope(const QString &binId, int clipId, size_t offset, size_t length, size_t startPos)
     : m_offset(offset)
@@ -59,7 +58,11 @@ AudioEnvelope::~AudioEnvelope()
 
 void AudioEnvelope::startComputeEnvelope()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     m_audioSummary = QtConcurrent::run(this, &AudioEnvelope::loadAndNormalizeEnvelope);
+#else
+    m_audioSummary = QtConcurrent::run(&AudioEnvelope::loadAndNormalizeEnvelope, this);
+#endif
     m_watcher.setFuture(m_audioSummary);
 }
 
@@ -94,7 +97,7 @@ const std::vector<qint64> &AudioEnvelope::envelope()
 
 AudioEnvelope::AudioSummary AudioEnvelope::loadAndNormalizeEnvelope() const
 {
-    qCDebug(KDENLIVE_LOG) << "Loading envelope ...";
+    qCDebug(KDENLIVE_LOG) << "Loading envelope …";
     AudioSummary summary(m_envelopeSize);
     if (!m_info || m_info->size() < 1) {
         return summary;
@@ -120,7 +123,7 @@ AudioEnvelope::AudioSummary AudioEnvelope::loadAndNormalizeEnvelope() const
         pCore->displayMessage(i18n("Processing data analysis"), ProcessingJobMessage, int(100 * i / max));
     }
     qCDebug(KDENLIVE_LOG) << "Calculating the envelope (" << m_envelopeSize << " frames) took " << t.elapsed() << " ms.";
-    qCDebug(KDENLIVE_LOG) << "Normalizing envelope ...";
+    qCDebug(KDENLIVE_LOG) << "Normalizing envelope …";
     const qint64 meanBeforeNormalization =
         std::accumulate(summary.audioAmplitudes.begin(), summary.audioAmplitudes.end(), 0LL) / qint64(summary.audioAmplitudes.size());
 
