@@ -3,8 +3,7 @@ SPDX-FileCopyrightText: 2012 Simon A. Eugster (Granjow)  <simon.eu@gmail.com>
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef AUDIOSTREAMINFO_H
-#define AUDIOSTREAMINFO_H
+#pragma once
 
 #include <QString>
 #include <QMap>
@@ -54,5 +53,3 @@ private:
     int m_bitRate;
     QString m_samplingFormat;
 };
-
-#endif // AUDIOSTREAMINFO_H
