@@ -36,6 +36,7 @@ class QLabel;
 class GLWidget;
 class MonitorAudioLevel;
 class MonitorProxy;
+class MarkerSortModel;
 
 namespace Mlt {
 class Profile;
@@ -66,7 +67,8 @@ public:
     void resetProfile();
     /** @brief Rebuild consumers after a property change */
     void resetConsumer(bool fullReset);
-    void setupMenu(QMenu *goMenu, QMenu *overlayMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu = nullptr, QAction *loopClip = nullptr);
+    void setupMenu(QMenu *goMenu, QMenu *overlayMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu = nullptr, QAction *loopClip = nullptr,
+                   MonitorManager *manager = nullptr);
     const QString activeClipId();
     int position();
     void updateTimecodeFormat();
@@ -110,6 +112,8 @@ public:
     /** @brief Set a property on the Qml scene **/
     void setQmlProperty(const QString &name, const QVariant &value);
     void displayAudioMonitor(bool isActive);
+    /** @brief Set the guides list model to currently active item (bin clip or timeline) **/
+    void updateGuidesList();
     /** @brief Prepare split effect from timeline clip producer **/
     void activateSplit();
     /** @brief Clear monitor display **/
@@ -316,7 +320,7 @@ public slots:
     void slotLoadClipZone(const QPoint &zone);
     void slotSeekToNextSnap();
     void slotSeekToPreviousSnap();
-    void adjustRulerSize(int length, const std::shared_ptr<MarkerListModel> &markerModel = nullptr);
+    void adjustRulerSize(int length, const std::shared_ptr<MarkerSortModel> &markerModel = nullptr);
     void setTimePos(const QString &pos);
     /** @brief Display the on monitor effect scene (to adjust geometry over monitor). */
     void slotShowEffectScene(MonitorSceneType sceneType, bool temporary = false, const QVariant &sceneData = QVariant());
