@@ -4,8 +4,7 @@
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef MONITORMANAGER_H
-#define MONITORMANAGER_H
+#pragma once
 
 #include "monitor.h"
 
@@ -71,8 +70,9 @@ public:
 public slots:
 
     /** @brief Activates a monitor.
-     * @param name name of the monitor to activate */
-    bool activateMonitor(Kdenlive::MonitorId name);
+     * @param name name of the monitor to activate
+     * @param name raiseMonitor, will raise (bring to front) the monitor if true */
+    bool activateMonitor(Kdenlive::MonitorId name, bool raiseMonitor = true);
     void slotPlay();
     void slotPause();
     void slotPlayZone();
@@ -168,5 +168,3 @@ signals:
     /** @brief monitor scaling was changed, update select action */
     void scalingChanged();
 };
-
-#endif
