@@ -117,7 +117,7 @@ void MonitorProxy::positionFromConsumer(int pos, bool playing)
 
 void MonitorProxy::setMarker(const QString &comment, const QColor &color)
 {
-    if (m_markerComment == comment) {
+    if (m_markerComment == comment && color == m_markerColor) {
         return;
     }
     m_markerComment = comment;
@@ -523,6 +523,6 @@ void MonitorProxy::addEffect(const QString &effectData, const QString &effectSou
                                   Q_ARG(QStringList, effectInfo));
     } else {
         // Dropped in project monitor
-        emit addTimelineEffect(effectInfo);
+        QMetaObject::invokeMethod(this, "addTimelineEffect", Qt::QueuedConnection, Q_ARG(QStringList, effectInfo));
     }
 }
