@@ -4,19 +4,18 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef REOURCEWIDGET_H
-#define REOURCEWIDGET_H
+#pragma once
 
-#include "ui_resourcewidget_ui.h"
 #include "providersrepository.hpp"
+#include "ui_resourcewidget_ui.h"
 
-#include <QWidget>
-#include <QUrl>
-#include <QNetworkReply>
-#include <QTemporaryFile>
-#include <QSlider>
 #include <QListWidgetItem>
+#include <QNetworkReply>
 #include <QProcess>
+#include <QSlider>
+#include <QTemporaryFile>
+#include <QUrl>
+#include <QWidget>
 #include <QtNetworkAuth>
 
 const int imageRole = Qt::UserRole;
@@ -78,5 +77,3 @@ signals:
     void addLicenseInfo(const QString &);
     void previewClip(const QString &path, const QString &title);
 };
-
-#endif // REOURCEWIDGET_H
