@@ -9,10 +9,10 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "core.h"
 #include "kdenlive_debug.h"
 
+#include <KLocalizedString>
 #include <QMenu>
 #include <QMimeData>
 #include <QMouseEvent>
-#include <klocalizedstring.h>
 
 NotesWidget::NotesWidget(QWidget *parent)
     : QTextEdit(parent)
@@ -196,7 +196,9 @@ void NotesWidget::createMarkers()
 void NotesWidget::addProjectNote()
 {
     if (!textCursor().atBlockStart()) {
-        textCursor().movePosition(QTextCursor::EndOfBlock);
+        QTextCursor cur = textCursor();
+        cur.movePosition(QTextCursor::EndOfBlock);
+        setTextCursor(cur);
         insertPlainText(QStringLiteral("\n"));
     }
     emit insertNotesTimecode();
@@ -204,9 +206,10 @@ void NotesWidget::addProjectNote()
 
 void NotesWidget::addTextNote(const QString &text)
 {
-    if (!textCursor().atBlockStart()) {
-        textCursor().movePosition(QTextCursor::EndOfBlock);
-        insertPlainText(QStringLiteral("\n"));
+    if (!textCursor().atEnd()) {
+        QTextCursor cur = textCursor();
+        cur.movePosition(QTextCursor::End);
+        setTextCursor(cur);
     }
     emit insertTextNote(text);
 }
