@@ -6,6 +6,9 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #pragma once
 
+#include "dialogs/encodingprofilesdialog.h"
+#include "guidecategories.h"
+
 #include <QDialog>
 #include <QPushButton>
 
@@ -22,8 +25,9 @@ public:
     ProjectSettings(KdenliveDoc *doc, QMap<QString, QString> metadata, QStringList lumas, int videotracks, int audiotracks, int audiochannels, const QString &projectPath,
                     bool readOnlyTracks, bool unsavedProject, QWidget *parent = nullptr);
     QString selectedProfile() const;
-    QUrl selectedFolder() const;
     QPair<int, int> tracks() const;
+    const QStringList guidesCategories() const;
+    const QMap<int, int> remapGuidesCategories() const;
     int audioChannels() const;
     bool enableVideoThumbs() const;
     bool enableAudioThumbs() const;
@@ -58,14 +62,12 @@ private slots:
     void slotExportToText();
     /** @brief Update the displayed proxy parameters when user changes selection. */
     void slotUpdateProxyParams();
-    void slotUpdatePreviewParams();
     /** @brief Insert a new metadata field. */
     void slotAddMetadataField();
     /** @brief Delete current metadata field. */
     void slotDeleteMetadataField();
     /** @brief Display proxy profiles management dialog. */
     void slotManageEncodingProfile();
-    void slotManagePreviewProfile();
     /** @brief Open editor for metadata item. */
     void slotEditMetadata(QTreeWidgetItem *, int);
     /** @brief Shows external proxy settings. */
@@ -93,8 +95,10 @@ private:
     QString m_previewparams;
     QString m_previewextension;
     QString m_initialExternalProxyProfile;
+    EncodingTimelinePreviewProfilesChooser *m_tlPreviewProfiles;
+    GuideCategories *m_guidesCategories;
     /** @brief Fill the proxy profiles combobox. */
-    void loadPreviewProfiles();
+    // void loadPreviewProfiles();
 
 signals:
     /** @brief User deleted proxies, so disable them in project. */
