@@ -26,6 +26,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QStandardPaths>
 #include <QTabWidget>
 #include <QToolButton>
+#include <QToolTip>
 #include <QTreeWidget>
 #include <QVBoxLayout>
 
@@ -150,27 +151,37 @@ TemporaryData::TemporaryData(KdenliveDoc *doc, bool currentProjectOnly, QWidget
     QDir global = m_doc->getCacheDir(SystemCacheRoot, &ok);
     QDir proxyFolder(global.absoluteFilePath(QStringLiteral("proxy")));
     gProxyPath->setText(QString("<a href='#'>%1</a>").arg(proxyFolder.absolutePath()));
-    connect(gProxyPath, &QLabel::linkActivated, [proxyFolder]() {
-        QDesktopServices::openUrl(QUrl::fromLocalFile(proxyFolder.absolutePath()));
-    });
+    connect(gProxyPath, &QLabel::linkActivated, [proxyFolder]() { QDesktopServices::openUrl(QUrl::fromLocalFile(proxyFolder.absolutePath())); });
 
     // Backup data
     connect(gBackupClean, &QToolButton::clicked, this, &TemporaryData::cleanBackup);
     connect(gBackupDelete, &QToolButton::clicked, this, &TemporaryData::deleteBackup);
     QDir backupFolder(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/.backup"));
     gBackupPath->setText(QString("<a href='#'>%1</a>").arg(backupFolder.absolutePath()));
-    connect(gBackupPath, &QLabel::linkActivated, [backupFolder]() {
-        QDesktopServices::openUrl(QUrl::fromLocalFile(backupFolder.absolutePath()));
-    });
+    connect(gBackupPath, &QLabel::linkActivated, [backupFolder]() { QDesktopServices::openUrl(QUrl::fromLocalFile(backupFolder.absolutePath())); });
 
     // Config cleanup age
     gCleanupSpin->setSuffix(i18np(" month", " months", KdenliveSettings::cleanCacheMonths()));
     gCleanupSpin->setValue(KdenliveSettings::cleanCacheMonths());
-    connect(gCleanupSpin, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, [&] (int value) {
+    connect(gCleanupSpin, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, [&](int value) {
         KdenliveSettings::setCleanCacheMonths(value);
         gCleanupSpin->setSuffix(i18np(" month", " months", KdenliveSettings::cleanCacheMonths()));
     });
 
+    // Setup help text
+    help_cached->setToolTip(i18n("<b>Cached data</b> is composed of clip thumbnails and timeline preview videos. Deleting is safe, all data can be recreated "
+                                 "on project opening.<br/><b>Backup data</b> is an archive of previous versions of your project files. Useful if you need to "
+                                 "recover a previous version of a project. This data cannot be recovered.<br/><b>Proxy clips</b> are lower resolution video "
+                                 "files used for faster editing. Deleting is safe, proxy clips can be recreated if you have the original source clips."));
+    connect(help_cached, &QToolButton::clicked, this, [this]() { QToolTip::showText(QCursor::pos(), help_cached->toolTip()); });
+
+    // Cache info message
+    cache_info->hide();
+    QAction *a = new QAction(QIcon::fromTheme(QStringLiteral("edit-clear-history")), i18n("Cleanup"), this);
+    cache_info->setText(i18n("Your cache and backup data exceeds %1, cleanup is recommended.", KIO::convertSize(1048576 * KdenliveSettings::maxcachesize())));
+    cache_info->addAction(a);
+    connect(a, &QAction::triggered, this, &TemporaryData::slotCleanUp);
+
     processBackupDirectories();
 
     connect(listWidget, &QTreeWidget::itemSelectionChanged, this, &TemporaryData::refreshGlobalPie);
@@ -178,10 +189,10 @@ TemporaryData::TemporaryData(KdenliveDoc *doc, bool currentProjectOnly, QWidget
     bool globalOnly = pCore->bin()->isEmpty();
     if (currentProjectOnly) {
         tabWidget->removeTab(1);
-        //globalPage->setEnabled(false);
+        // globalPage->setEnabled(false);
     } else if (globalOnly) {
         tabWidget->removeTab(0);
-        //projectPage->setEnabled(false);
+        // projectPage->setEnabled(false);
     }
 
     if (globalOnly && !currentProjectOnly) {
@@ -310,7 +321,10 @@ void TemporaryData::deletePreview()
     if (!ok) {
         return;
     }
-    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the preview folder:\n%1\nPreview folder contains the timeline previews, and can be recreated with the source project.", dir.absolutePath())) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(
+            this,
+            i18n("Delete all data in the preview folder:\n%1\nPreview folder contains the timeline previews, and can be recreated with the source project.",
+                 dir.absolutePath())) != KMessageBox::Continue) {
         return;
     }
     if (dir.dirName() == QLatin1String("preview")) {
@@ -324,7 +338,9 @@ void TemporaryData::deletePreview()
 void TemporaryData::deleteBackup()
 {
     QDir backupFolder(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/.backup"));
-    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the backup folder:\n%1\nA copy of all your project files is kept in this folder for recovery in case of corruption.", backupFolder.absolutePath())) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(
+            this, i18n("Delete all data in the backup folder:\n%1\nA copy of all your project files is kept in this folder for recovery in case of corruption.",
+                       backupFolder.absolutePath())) != KMessageBox::Continue) {
         return;
     }
     if (backupFolder.dirName() == QLatin1String(".backup")) {
@@ -340,17 +356,21 @@ void TemporaryData::cleanBackup()
     QFileInfoList files = backupFolder.entryInfoList(QDir::Files, QDir::Time);
     QStringList oldFiles;
     QDateTime current = QDateTime::currentDateTime();
+    KIO::filesize_t totalSize = 0;
     for (const QFileInfo &f : qAsConst(files)) {
         if (f.lastModified().addMonths(KdenliveSettings::cleanCacheMonths()) < current) {
             oldFiles << f.fileName();
+            totalSize += f.size();
         }
     }
     if (oldFiles.isEmpty()) {
         KMessageBox::information(this, i18n("No backup data older than %1 months was found.", KdenliveSettings::cleanCacheMonths()));
         return;
     }
-    if (KMessageBox::warningContinueCancelList(this, i18n("This will delete backup data for projects older than %1 months.", KdenliveSettings::cleanCacheMonths()), oldFiles) !=
-        KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancelList(
+            this,
+            i18n("This will delete backup data (%1) for projects older than %2 months.", KIO::convertSize(totalSize), KdenliveSettings::cleanCacheMonths()),
+            oldFiles) != KMessageBox::Continue) {
         return;
     }
     if (backupFolder.dirName() == QLatin1String(".backup")) {
@@ -370,15 +390,20 @@ void TemporaryData::cleanCache()
     if (!root) {
         return;
     }
-    // Find old backup data ( older than 6 months )
+    // Find old backup data ( older than x months ), or very small (that can be quickly recreated)
     size_t total = 0;
     QDateTime current = QDateTime::currentDateTime();
     int max = root->childCount();
-    for (int i = 0; i< max; i++) {
+    for (int i = 0; i < max; i++) {
         QTreeWidgetItem *child = root->child(i);
-        if (child->data(2, Qt::UserRole).toDateTime().addMonths(KdenliveSettings::cleanCacheMonths()) < current) {
+        if (emptyDirs.contains(child)) {
+            continue;
+        }
+        size_t childSize = size_t(child->data(1, Qt::UserRole).toLongLong());
+        // Check temporary folders with content less than 200kB or old data
+        if (childSize < 200000 || child->data(2, Qt::UserRole).toDateTime().addMonths(KdenliveSettings::cleanCacheMonths()) < current) {
             emptyDirs << child;
-            total += size_t(child->data(1, Qt::UserRole).toLongLong());
+            total += childSize;
         }
     }
     QStringList folders;
@@ -390,8 +415,11 @@ void TemporaryData::cleanCache()
         return;
     }
 
-    if (KMessageBox::warningContinueCancelList(this, i18n("This will delete cache data (%1) for missing projects or projects older than %2 months.", KIO::convertSize(total), KdenliveSettings::cleanCacheMonths()), folders) !=
-        KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancelList(this,
+                                               i18n("This will delete cache data (%1) for projects that were deleted, have very few cached data or older than "
+                                                    "%2 months. All cached data can be recreated from the source files on project opening.",
+                                                    KIO::convertSize(total), KdenliveSettings::cleanCacheMonths()),
+                                               folders) != KMessageBox::Continue) {
         return;
     }
     deleteCache(folders);
@@ -410,8 +438,11 @@ void TemporaryData::deleteProjectProxy()
     }
     dir.setNameFilters(m_proxies);
     QStringList files = dir.entryList(QDir::Files);
-    if (KMessageBox::warningContinueCancelList(this, i18n("Delete all project data in the proxy folder:\n%1\nProxy folder contains the proxy clips for all your projects. This proxies can be recreated from the source clips.", dir.absolutePath()), files) !=
-        KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancelList(this,
+                                               i18n("Delete all project data in the proxy folder:\n%1\nProxy folder contains the proxy clips for all your "
+                                                    "projects. This proxies can be recreated from the source clips.",
+                                                    dir.absolutePath()),
+                                               files) != KMessageBox::Continue) {
         return;
     }
     for (const QString &file : qAsConst(files)) {
@@ -428,7 +459,9 @@ void TemporaryData::deleteAudio()
     if (!ok) {
         return;
     }
-    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache audio folder:\n%1\nThis folder contains the data for audio thumbnails in this project.", dir.absolutePath())) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(
+            this, i18n("Delete all data in the cache audio folder:\n%1\nThis folder contains the data for audio thumbnails in this project.",
+                       dir.absolutePath())) != KMessageBox::Continue) {
         return;
     }
     if (dir.dirName() == QLatin1String("audiothumbs")) {
@@ -445,7 +478,9 @@ void TemporaryData::deleteThumbs()
     if (!ok) {
         return;
     }
-    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache thumbnail folder:\n%1\nThis folder contains the data for video thumbnails in this project.", dir.absolutePath())) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(
+            this, i18n("Delete all data in the cache thumbnail folder:\n%1\nThis folder contains the data for video thumbnails in this project.",
+                       dir.absolutePath())) != KMessageBox::Continue) {
         return;
     }
     if (dir.dirName() == QLatin1String("videothumbs")) {
@@ -462,7 +497,9 @@ void TemporaryData::deleteCurrentCacheData(bool warn)
     if (!ok) {
         return;
     }
-    if (warn && KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache folder:\n%1\nCache folder contains the audio and video thumbnails, as well as timeline previews. All this data will be recreated on project opening.", dir.absolutePath())) != KMessageBox::Continue) {
+    if (warn && KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache folder:\n%1\nCache folder contains the audio and video thumbnails, "
+                                                              "as well as timeline previews. All this data will be recreated on project opening.",
+                                                              dir.absolutePath())) != KMessageBox::Continue) {
         return;
     }
     if (dir.dirName() == m_doc->getDocumentProperty(QStringLiteral("documentid"))) {
@@ -513,6 +550,8 @@ void TemporaryData::gotBackupSize(KJob *job)
     if (sourceJob->totalFiles() == 0) {
         total = 0;
     }
+    m_totalBackup = total;
+    refreshWarningMessage();
     gBackupSize->setText(KIO::convertSize(total));
 }
 
@@ -587,13 +626,16 @@ void TemporaryData::gotFolderSize(KJob *job)
     item->setData(0, Qt::UserRole, m_processingDirectory);
     item->setText(1, KIO::convertSize(total));
     QDateTime date = QFileInfo(dir.absolutePath()).lastModified();
-    item->setText(2, date.toString(Qt::SystemLocaleShortDate));
+    QLocale locale;
+    item->setText(2, locale.toString(date, QLocale::ShortFormat));
     item->setData(1, Qt::UserRole, total);
     item->setData(2, Qt::UserRole, date);
     listWidget->addTopLevelItem(item);
     listWidget->resizeColumnToContents(0);
     listWidget->resizeColumnToContents(1);
     if (m_globalDirectories.isEmpty()) {
+        // Processing done, check total size
+        refreshWarningMessage();
         gTotalSize->setText(KIO::convertSize(m_totalGlobal));
         listWidget->setCurrentItem(listWidget->topLevelItem(0));
     } else {
@@ -601,6 +643,16 @@ void TemporaryData::gotFolderSize(KJob *job)
     }
 }
 
+void TemporaryData::refreshWarningMessage()
+{
+    if (KdenliveSettings::maxcachesize() > 0 && (m_totalGlobal + m_totalBackup > KIO::filesize_t(1048576) * KdenliveSettings::maxcachesize())) {
+        // Cache larger than x MB, warn
+        cache_info->animatedShow();
+    } else {
+        cache_info->animatedHide();
+    }
+}
+
 void TemporaryData::refreshGlobalPie()
 {
     QList<QTreeWidgetItem *> list = listWidget->selectedItems();
@@ -629,8 +681,11 @@ void TemporaryData::deleteSelected()
             folders << current->data(0, Qt::UserRole).toString();
         }
     }
-    if (KMessageBox::warningContinueCancelList(this, i18n("Delete the following cache folders from\n%1\nCache folders contains the audio and video thumbnails, as well as timeline previews. All this data will be recreated on project opening.", m_globalDir.absolutePath()), folders) !=
-        KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancelList(this,
+                                               i18n("Delete the following cache folders from\n%1\nCache folders contains the audio and video thumbnails, as "
+                                                    "well as timeline previews. All this data will be recreated on project opening.",
+                                                    m_globalDir.absolutePath()),
+                                               folders) != KMessageBox::Continue) {
         return;
     }
     deleteCache(folders);
@@ -685,10 +740,11 @@ void TemporaryData::cleanProxy()
         }
     }
     if (oldFiles.isEmpty()) {
-        KMessageBox::information(this, i18n("No proxy clips older than %1 months was found.", KdenliveSettings::cleanCacheMonths()));
+        KMessageBox::information(this, i18n("No proxy clip older than %1 months found.", KdenliveSettings::cleanCacheMonths()));
         return;
     }
-    if (KMessageBox::warningContinueCancelList(this, i18n("Delete the following proxy clips (%1)\nProxy clips can be recreated on project opening.", KIO::convertSize(size)), oldFiles) !=
+    if (KMessageBox::warningContinueCancelList(
+            this, i18n("Delete the following proxy clips (%1)\nProxy clips can be recreated on project opening.", KIO::convertSize(size)), oldFiles) !=
         KMessageBox::Continue) {
         return;
     }
@@ -697,3 +753,9 @@ void TemporaryData::cleanProxy()
     }
     processProxyDirectory();
 }
+
+void TemporaryData::slotCleanUp()
+{
+    cleanCache();
+    cleanBackup();
+}
