@@ -6,13 +6,14 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "notesplugin.h"
 #include "core.h"
 #include "dialogs/noteswidget.h"
-#include "mainwindow.h"
 #include "doc/kdenlivedoc.h"
+#include "klocalizedstring.h"
+#include "mainwindow.h"
 #include "monitor/monitormanager.h"
 #include "project/projectmanager.h"
-#include "klocalizedstring.h"
 
 #include <QStyle>
+#include <QVBoxLayout>
 
 NotesPlugin::NotesPlugin(ProjectManager *projectManager)
     : QObject(projectManager)
@@ -33,7 +34,7 @@ NotesPlugin::NotesPlugin(ProjectManager *projectManager)
     connect(m_widget, &NotesWidget::insertTextNote, this, &NotesPlugin::slotInsertText);
     connect(m_widget, &NotesWidget::reAssign, this, &NotesPlugin::slotReAssign);
     m_widget->setTabChangesFocus(true);
-    m_widget->setPlaceholderText(i18n("Enter your project notes here ..."));
+    m_widget->setPlaceholderText(i18n("Enter your project notes here …"));
     m_notesDock = pCore->window()->addDock(i18n("Project Notes"), QStringLiteral("notes_widget"), container);
     m_notesDock->close();
     connect(projectManager, &ProjectManager::docOpened, this, &NotesPlugin::setProject);
@@ -77,17 +78,18 @@ void NotesPlugin::slotInsertTimecode()
     } else {
         int frames = pCore->monitorManager()->projectMonitor()->position();
         QString position = pCore->timecode().getTimecodeFromFrames(frames);
-        QPair <int,QString>currentTrackInfo = pCore->currentTrackInfo();
+        QPair<int, QString> currentTrackInfo = pCore->currentTrackInfo();
         if (currentTrackInfo.first != -1) {
             // Insert timeline position with track reference
-            m_widget->insertHtml(QString("<a href=\"%1?%2\">%3 %4</a> ").arg(QString::number(frames), QString::number(currentTrackInfo.first), currentTrackInfo.second, position));
+            m_widget->insertHtml(QString("<a href=\"%1?%2\">%3 %4</a> ")
+                                     .arg(QString::number(frames), QString::number(currentTrackInfo.first), currentTrackInfo.second, position));
         } else {
             m_widget->insertHtml(QString("<a href=\"%1\">%2</a> ").arg(QString::number(frames), position));
         }
     }
 }
 
-void NotesPlugin::slotReAssign(QStringList anchors, QList <QPoint> points)
+void NotesPlugin::slotReAssign(const QStringList &anchors, const QList<QPoint> &points)
 {
     const QString binId = pCore->monitorManager()->clipMonitor()->activeClipId();
     int ix = 0;
@@ -96,7 +98,7 @@ void NotesPlugin::slotReAssign(QStringList anchors, QList <QPoint> points)
         pCore->displayMessage(i18n("Cannot perform assign"), ErrorMessage);
         return;
     }
-    for (const QString & a : anchors) {
+    for (const QString &a : anchors) {
         QPoint pt = points.at(ix);
         QString updatedLink = a;
         int position = 0;
@@ -108,7 +110,6 @@ void NotesPlugin::slotReAssign(QStringList anchors, QList <QPoint> points)
                 updatedLink.prepend(QString("%1#").arg(binId));
             }
         } else {
-            updatedLink = a;
             position = a.toInt();
             if (!binId.isEmpty()) {
                 updatedLink.prepend(QString("%1#").arg(binId));
