@@ -5,8 +5,7 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef SPEECHTOTEXT_H
-#define SPEECHTOTEXT_H
+#pragma once
 
 #include "abstractpythoninterface.h"
 
@@ -34,5 +33,3 @@ signals:
     void subtitleFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
 };
-
-#endif
