@@ -3,8 +3,7 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef CLIPSNAPMODEL_H
-#define CLIPSNAPMODEL_H
+#pragma once
 
 #include "snapmodel.hpp"
 
@@ -40,7 +39,6 @@ public:
     /** @brief Retrieve all snap points */
     void allSnaps(std::vector<int> &snaps, int offset = 0) const;
 
-
 private:
     std::weak_ptr<SnapModel> m_registeredSnap;
     std::weak_ptr<MarkerListModel> m_parentModel;
@@ -52,7 +50,4 @@ private:
     double m_speed{1.};
     void addAllSnaps();
     void removeAllSnaps();
-
 };
-
-#endif
