@@ -326,7 +326,8 @@ void GroupsModel::setGroup(int id, int groupId, bool changeState)
     }
 }
 
-QString GroupsModel::debugString() {
+QString GroupsModel::debugString()
+{
     QString string;
     for (const auto &item : m_downLink) {
         QStringList leafs;
@@ -717,7 +718,8 @@ QJsonObject GroupsModel::toJson(int gid) const
         // in that case we have a clip or composition
         if (auto ptr = m_parent.lock()) {
             Q_ASSERT(ptr->isClip(gid) || ptr->isComposition(gid) || ptr->isSubTitle(gid));
-            currentGroup.insert(QLatin1String("leaf"), QJsonValue(QLatin1String(ptr->isClip(gid) ? "clip" : ptr->isComposition(gid) ? "composition" : "subtitle")));
+            currentGroup.insert(QLatin1String("leaf"),
+                                QJsonValue(QLatin1String(ptr->isClip(gid) ? "clip" : ptr->isComposition(gid) ? "composition" : "subtitle")));
             int track = ptr->isSubTitle(gid) ? -2 : ptr->getTrackPosition(ptr->getItemTrackId(gid));
             int pos = ptr->getItemPosition(gid);
             currentGroup.insert(QLatin1String("data"), QJsonValue(QString("%1:%2").arg(track).arg(pos)));
@@ -732,8 +734,7 @@ QJsonObject GroupsModel::toJson(int gid) const
 const QString GroupsModel::toJson() const
 {
     std::unordered_set<int> roots;
-    std::transform(m_groupIds.begin(), m_groupIds.end(), std::inserter(roots, roots.begin()),
-                   [&](decltype(*m_groupIds.begin()) g) { 
+    std::transform(m_groupIds.begin(), m_groupIds.end(), std::inserter(roots, roots.begin()), [&](decltype(*m_groupIds.begin()) g) {
         const int parentId = getRootId(g.first);
         if (getType(parentId) == GroupType::Selection) {
             // Don't insert selection group, only its child groups
@@ -841,7 +842,7 @@ bool GroupsModel::fromJson(const QString &data)
     return ok;
 }
 
-void GroupsModel::adjustOffset(QJsonArray &updatedNodes, const QJsonObject &childObject, int offset, const QMap<int, int> &trackMap)
+void GroupsModel::adjustOffset(QJsonArray &updatedNodes, const QJsonObject &childObject, int offset, const QMap<int, int> &trackMap, double ratio)
 {
     auto value = childObject.value(QLatin1String("children"));
     auto children = value.toArray();
@@ -855,7 +856,7 @@ void GroupsModel::adjustOffset(QJsonArray &updatedNodes, const QJsonObject &chil
             if (auto ptr = m_parent.lock()) {
                 QString cur_data = child.value(QLatin1String("data")).toString();
                 int trackId = cur_data.section(":", 0, 0).toInt();
-                int pos = cur_data.section(":", 1, 1).toInt();
+                int pos = cur_data.section(":", 1, 1).toInt() * ratio;
                 int trackPos = trackId == -2 ? -2 : ptr->getTrackPosition(trackMap.value(trackId));
                 pos += offset;
                 child.insert(QLatin1String("data"), QJsonValue(QString("%1:%2").arg(trackPos).arg(pos)));
@@ -872,7 +873,7 @@ void GroupsModel::adjustOffset(QJsonArray &updatedNodes, const QJsonObject &chil
     }
 }
 
-bool GroupsModel::fromJsonWithOffset(const QString &data, const QMap<int, int> &trackMap, int offset, Fun &undo, Fun &redo)
+bool GroupsModel::fromJsonWithOffset(const QString &data, const QMap<int, int> &trackMap, int offset, double ratio, Fun &undo, Fun &redo)
 {
     Fun local_undo = []() { return true; };
     Fun local_redo = []() { return true; };
@@ -899,7 +900,7 @@ bool GroupsModel::fromJsonWithOffset(const QString &data, const QMap<int, int> &
             continue;
         }
         // Adjust offset
-        adjustOffset(updatedNodes, obj, offset, trackMap);
+        adjustOffset(updatedNodes, obj, offset, trackMap, ratio);
         QJsonObject currentGroup;
         currentGroup.insert(QLatin1String("children"), QJsonValue(updatedNodes));
         currentGroup.insert(QLatin1String("type"), QJsonValue(groupTypeToStr(type)));
