@@ -98,13 +98,55 @@ QModelIndex TimelineItemModel::index(int row, int column, const QModelIndex &par
     return index(clipIndex, 0, index(trackIndex));
 }*/
 
+bool TimelineItemModel::addTracksAtPosition(int position, int tracksCount, QString &trackName, bool addAudioTrack, bool addAVTrack, bool addRecTrack)
+{
+    Fun undo = []() { return true; };
+    Fun redo = []() { return true; };
+    bool result = true;
+
+    int insertionIndex = position;
+
+    for (int ix = 0; ix < tracksCount; ++ix) {
+        int newTid;
+        result = requestTrackInsertion(insertionIndex, newTid, trackName, addAudioTrack, undo, redo);
+        // bump up insertion index so that the next new track goes after this one
+        insertionIndex++;
+        if (result) {
+            if (addAVTrack) {
+                int newTid2;
+                int mirrorPos = 0;
+                int mirrorId = getMirrorAudioTrackId(newTid);
+                if (mirrorId > -1) {
+                    mirrorPos = getTrackMltIndex(mirrorId);
+                }
+                result = requestTrackInsertion(mirrorPos, newTid2, trackName, true, undo, redo);
+                // because we also added an audio track, we need to put the next
+                // new track's index is 1 further
+                insertionIndex++;
+            }
+            if (addRecTrack) {
+                setTrackProperty(newTid, "kdenlive:audio_rec", QStringLiteral("1"));
+            }
+        } else {
+            break;
+        }
+    }
+    if (result) {
+        pCore->pushUndo(undo, redo, addAVTrack || tracksCount > 1 ? i18nc("@action", "Insert Tracks") : i18nc("@action", "Insert Track"));
+        return true;
+    } else {
+        undo();
+        return false;
+    }
+}
+
 QModelIndex TimelineItemModel::makeClipIndexFromID(int clipId) const
 {
     Q_ASSERT(m_allClips.count(clipId) > 0);
     int trackId = m_allClips.at(clipId)->getCurrentTrackId();
     if (trackId == -1) {
         // Clip is not inserted in a track
-        qDebug() << "/// WARNING; INVALID CLIP INDEX REQUESTED: "<<clipId<<"\n________________";
+        qDebug() << "/// WARNING; INVALID CLIP INDEX REQUESTED: " << clipId << "\n________________";
         return {};
     }
     int row = getTrackById_const(trackId)->getRowfromClip(clipId);
@@ -478,24 +520,6 @@ void TimelineItemModel::setTrackName(int trackId, const QString &text)
     PUSH_UNDO(undo_lambda, redo_lambda, i18n("Rename Track"));
 }
 
-void TimelineItemModel::hideTrack(int trackId, bool hide)
-{
-    QWriteLocker locker(&m_lock);
-    bool isAudio = isAudioTrack(trackId);
-    QString state = hide ? (isAudio ? "1" : "2") : "3";
-    QString previousState = getTrackProperty(trackId, QStringLiteral("hide")).toString();
-    Fun undo_lambda = [this, trackId, previousState]() {
-        setTrackProperty(trackId, QStringLiteral("hide"), previousState);
-        return true;
-    };
-    Fun redo_lambda = [this, trackId, state]() {
-        setTrackProperty(trackId, QStringLiteral("hide"), state);
-        return true;
-    };
-    redo_lambda();
-    PUSH_UNDO(undo_lambda, redo_lambda, state == QLatin1String("3") ? i18n("Hide Track") : i18n("Enable Track"));
-}
-
 void TimelineItemModel::setTrackProperty(int trackId, const QString &name, const QString &value)
 {
     std::shared_ptr<TrackModel> track = getTrackById(trackId);
@@ -513,7 +537,7 @@ void TimelineItemModel::setTrackProperty(int trackId, const QString &name, const
         roles.push_back(IsDisabledRole);
         if (!track->isAudioTrack()) {
             pCore->invalidateItem(ObjectId(ObjectType::TimelineTrack, trackId));
-            pCore->requestMonitorRefresh();
+            pCore->refreshProjectMonitorOnce();
             updateMultiTrack = true;
         }
     } else if (name == QLatin1String("kdenlive:timeline_active")) {
@@ -678,7 +702,8 @@ void TimelineItemModel::buildTrackCompositing(bool rebuild)
             transition->set_tracks(0, trackPos);
             field->plant_transition(*transition.get(), 0, trackPos);
             if (hasMixer) {
-                pCore->mixer()->registerTrack((*it)->getId(), (*it)->getTrackService(), getTrackTagById((*it)->getId()), (*it)->getProperty(QStringLiteral("kdenlive:track_name")).toString());
+                pCore->mixer()->registerTrack((*it)->getId(), (*it)->getTrackService(), getTrackTagById((*it)->getId()),
+                                              (*it)->getProperty(QStringLiteral("kdenlive:track_name")).toString());
                 connect(pCore->mixer(), &MixerManager::showEffectStack, this, &TimelineItemModel::showTrackEffectStack);
             }
         }
