@@ -3,8 +3,7 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef TIMELINEITEMMODEL_H
-#define TIMELINEITEMMODEL_H
+#pragma once
 
 #include "timelinemodel.hpp"
 #include "undohelper.hpp"
@@ -55,6 +54,11 @@ public:
     QHash<int, QByteArray> roleNames() const override;
     QModelIndex index(int row, int column = 0, const QModelIndex &parent = QModelIndex()) const override;
     // QModelIndex makeIndex(int trackIndex, int clipIndex) const;
+
+    /** @brief Add multiple tracks at a specific position (used by the Add Track
+     * dialog). Returns true if successful, false otherwise. */
+    bool addTracksAtPosition(int position, int tracksCount, QString &trackName, bool addAudioTrack, bool addAVTrack, bool addRecTrack);
+
     /** @brief Creates an index based on the ID of the clip*/
     QModelIndex makeClipIndexFromID(int clipId) const override;
     /** @brief Creates an index based on the ID of the compoition*/
@@ -72,7 +76,6 @@ public:
        @param text is the new track name.
     */
     Q_INVOKABLE void setTrackName(int trackId, const QString &text);
-    Q_INVOKABLE void hideTrack(int trackId, bool hide);
     /** @brief returns the lower video track index in timeline.
      **/
     int getFirstVideoTrackIndex() const;
@@ -105,4 +108,3 @@ signals:
     void trackVisibilityChanged();
     void showTrackEffectStack(int tid);
 };
-#endif
