@@ -81,6 +81,7 @@ private:
     Mlt::Tractor *m_tractor;
     Mlt::Playlist *m_previewTrack;
     Mlt::Playlist *m_overlayTrack;
+    bool m_warnOnCrash;
     int m_previewTrackIndex;
     /** @brief: The kdenlive renderer app. */
     QString m_renderer;
@@ -120,7 +121,7 @@ private:
     /** @brief Compare two chunks for usage by std::sort
      * @returns true if @param c1 is less than @param c2
      */
-    static bool chunkSort(const QVariant &c1, const QVariant &c2) { return c1.toString() < c2.toString(); };
+    static bool chunkSort(const QVariant &c1, const QVariant &c2) { return c1.toInt() < c2.toInt(); };
 
 private slots:
     /** @brief: To avoid filling the hard drive, remove preview undo history after 5 steps. */
