@@ -26,8 +26,7 @@ TransitionListWidget::TransitionListWidget(QWidget *parent)
     m_proxyModel->setSortRole(AssetTreeModel::NameRole);
     m_proxyModel->sort(0, Qt::AscendingOrder);
 
-    m_proxy = new TransitionListWidgetProxy(this);
-    rootContext()->setContextProperty("assetlist", m_proxy);
+    rootContext()->setContextProperty("assetlist", this);
     rootContext()->setContextProperty("assetListModel", m_proxyModel.get());
     rootContext()->setContextProperty("isEffectList", false);
     m_assetIconProvider = new AssetIconProvider(false);
@@ -48,13 +47,6 @@ QString TransitionListWidget::getMimeType(const QString &assetId) const
     return QStringLiteral("kdenlive/composition");
 }
 
-void TransitionListWidget::updateFavorite(const QModelIndex &index)
-{
-    emit m_proxyModel->dataChanged(index, index, QVector<int>());
-    m_proxyModel->reloadFilterOnFavorite();
-    emit reloadFavorites();
-}
-
 void TransitionListWidget::setFilterType(const QString &type)
 {
     if (type == "favorites") {
@@ -66,12 +58,10 @@ void TransitionListWidget::setFilterType(const QString &type)
     }
 }
 
-void TransitionListWidget::downloadNewLumas()
+void TransitionListWidget::refreshLumas()
 {
-    if (pCore->getNewStuff(QStringLiteral(":data/kdenlive_wipes.knsrc")) > 0) {
-        MltConnection::refreshLumas();
-        // TODO: refresh currently displayed trans ?
-    }
+    MltConnection::refreshLumas();
+    // TODO: refresh currently displayed trans ?
 }
 
 void TransitionListWidget::reloadCustomEffectIx(const QModelIndex &) {}
