@@ -49,10 +49,10 @@ Mlt::Properties *TransitionsRepository::getMetadata(const QString &assetId) cons
 
 void TransitionsRepository::parseCustomAssetFile(const QString &file_name, std::unordered_map<QString, Info> &customAssets) const
 {
-    QFile file(file_name);
     QDomDocument doc;
-    doc.setContent(&file, false);
-    file.close();
+    if (!Xml::docContentFromFile(doc, file_name, false)) {
+        return;
+    }
 
     QDomElement base = doc.documentElement();
     QDomNodeList transitions = doc.elementsByTagName(QStringLiteral("transition"));
@@ -168,20 +168,23 @@ bool TransitionsRepository::isComposition(const QString &transitionId) const
 
 const QString TransitionsRepository::getCompositingTransition()
 {
+    // Temporary hack to test the CI
+    if (!pCore->window()) {
+        return QStringLiteral("composite");
+    }
     if (KdenliveSettings::gpu_accel()) {
         return QStringLiteral("movit.overlay");
     }
     if (KdenliveSettings::preferredcomposite() != i18n("auto") && exists(KdenliveSettings::preferredcomposite())) {
         return KdenliveSettings::preferredcomposite();
     }
-    if (exists(QStringLiteral("frei0r.cairoblend"))) {
-        return QStringLiteral("frei0r.cairoblend");
-    }
-    if (exists(QStringLiteral("qtblend"))) {
-        return QStringLiteral("qtblend");
-    }
-    if (exists(QStringLiteral("composite"))) {
-        return QStringLiteral("composite");
+    QStringList trackComposites = KdenliveSettings::compositingList();
+    while (!trackComposites.isEmpty()) {
+        const QString &cmp = trackComposites.takeFirst();
+        if (exists(cmp)) {
+            qDebug() << ":::: USING TRACK COMPOSITING: " << cmp;
+            return cmp;
+        }
     }
     qWarning() << "no compositing found";
     return QString();
