@@ -20,14 +20,11 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <kconfigwidgets_version.h>
 
 ThemeManager::ThemeManager(QObject *parent)
     : KColorSchemeManager(parent)
 {
-#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 89, 0)
     setAutosaveChanges(false);
-#endif
     const auto schemePath(loadCurrentPath());
 
     // KColorSchemeManager includes a system color scheme option that reacts to system scheme changes.
