@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef THEMEMANAGER_H
-#define THEMEMANAGER_H
+#pragma once
 
 // Qt includes
 
@@ -18,26 +17,24 @@
 // KDE includes
 #include <KColorSchemeManager>
 
-class ThemeManager : public QAction
+class ThemeManager : public KColorSchemeManager
 {
     Q_OBJECT
 public:
     ThemeManager(QObject *parent);
-    QString currentSchemeName() const;
+    KActionMenu *menu() { return m_menu; };
 
 private Q_SLOTS:
     void slotSchemeChanged(const QString &path);
 
 private:
+    KActionMenu *m_menu;
+
     QString loadCurrentScheme() const;
     QString loadCurrentPath() const;
     void saveCurrentScheme(const QString & path);
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 67, 0)
-    QString currentDesktopDefaultScheme() const;
-#endif
+    QString currentSchemeName() const;
 
 signals:
     void themeChanged(const QString &name);
 };
-
-#endif /* THEMEMANAGER_H */
