@@ -1,3 +1,8 @@
+/*
+    SPDX-FileCopyrightText: 2018-2022 Jean-Baptiste Mardelle <jb@kdenlive.org>
+    SPDX-FileCopyrightText: 2017-2019 Nicolas Carion <french.ebook.lover@gmail.com>
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 #define CATCH_CONFIG_RUNNER
 #include "catch.hpp"
 
@@ -21,11 +26,16 @@ int main(int argc, char *argv[])
     app.setApplicationName(QStringLiteral("kdenlive"));
     std::unique_ptr<Mlt::Repository> repo(Mlt::Factory::init(nullptr));
     qputenv("MLT_TESTS", QByteArray("1"));
+    qSetMessagePattern(QStringLiteral("%{file}:%{line} – %{message}"));
     Core::build(QString(), true);
     MltConnection::construct(QString());
     pCore->projectItemModel()->buildPlaylist();
     // if Kdenlive is not installed, ensure we have one keyframable effect
     EffectsRepository::get()->reloadCustom(QFileInfo("../data/effects/audiobalance.xml").absoluteFilePath());
+    // init markers
+    for (int i = 0; i < 5; i++) {
+        pCore->markerTypes.insert(i, {QColor(30 * i, 30 * i, 30 * i), QString("cat %1").arg(i)});
+    }
 
     int result = Catch::Session().run(argc, argv);
     pCore->cleanup();
