@@ -1,3 +1,8 @@
+/*
+    SPDX-FileCopyrightText: 2018-2022 Jean-Baptiste Mardelle <jb@kdenlive.org>
+    SPDX-FileCopyrightText: 2022 Eric Jiang
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 #include "test_utils.hpp"
 #define private public
 #define protected public
@@ -27,7 +32,8 @@ TEST_CASE("Save File", "[SF]")
     SECTION("Simple insert and save")
     {
         // Create document
-        Mock<KdenliveDoc> docMock;
+        KdenliveDoc document(nullptr);
+        Mock<KdenliveDoc> docMock(document);
         // When(Method(docMock, getDocumentProperty)).AlwaysDo([](const QString &name, const QString &defaultValue) {
         //     Q_UNUSED(name) Q_UNUSED(defaultValue)
         //     qDebug() << "Intercepted call";
@@ -43,8 +49,7 @@ TEST_CASE("Save File", "[SF]")
 
         ProjectManager &mocked = pmMock.get();
         pCore->m_projectManager = &mocked;
-        pCore->m_projectManager->m_project = &mockedDoc;
-        pCore->m_projectManager->m_project->m_guideModel = guideModel;
+        mockedDoc.m_guideModel = guideModel;
 
         // We also mock timeline object to spy few functions and mock others
         TimelineItemModel tim(&profile_file, undoStack);
@@ -110,7 +115,8 @@ TEST_CASE("Save File", "[SF]")
     SECTION("Reopen and check in/out points")
     {
         // Create new document
-        Mock<KdenliveDoc> docMock;
+        KdenliveDoc document(nullptr);
+        Mock<KdenliveDoc> docMock(document);
         KdenliveDoc &mockedDoc = docMock.get();
 
         // We mock the project class so that the undoStack function returns our undoStack, and our mocked document
@@ -121,8 +127,7 @@ TEST_CASE("Save File", "[SF]")
 
         ProjectManager &mocked = pmMock.get();
         pCore->m_projectManager = &mocked;
-        pCore->m_projectManager->m_project = &mockedDoc;
-        pCore->m_projectManager->m_project->m_guideModel = guideModel;
+        mockedDoc.m_guideModel = guideModel;
 
         // We also mock timeline object to spy few functions and mock others
         TimelineItemModel tim(&profile_file, undoStack);
@@ -174,7 +179,8 @@ TEST_CASE("Save File", "[SF]")
     SECTION("Open a file with AV clips")
     {
         // Create new document
-        Mock<KdenliveDoc> docMock;
+        KdenliveDoc document(nullptr);
+        Mock<KdenliveDoc> docMock(document);
         KdenliveDoc &mockedDoc = docMock.get();
 
         // We mock the project class so that the undoStack function returns our undoStack, and our mocked document
@@ -190,8 +196,7 @@ TEST_CASE("Save File", "[SF]")
 
         ProjectManager &mocked = pmMock.get();
         pCore->m_projectManager = &mocked;
-        pCore->m_projectManager->m_project = &mockedDoc;
-        pCore->m_projectManager->m_project->m_guideModel = guideModel;
+        mockedDoc.m_guideModel = guideModel;
 
         // We also mock timeline object to spy few functions and mock others
         TimelineItemModel tim(&profile_file, undoStack);
@@ -266,7 +271,8 @@ TEST_CASE("Non-BMP Unicode", "[NONBMP]")
     {
 
         // Create document
-        Mock<KdenliveDoc> docMock;
+        KdenliveDoc document(nullptr);
+        Mock<KdenliveDoc> docMock(document);
         // When(Method(docMock, getDocumentProperty)).AlwaysDo([](const QString &name, const QString &defaultValue) {
         //     Q_UNUSED(name) Q_UNUSED(defaultValue)
         //     qDebug() << "Intercepted call";
@@ -282,8 +288,7 @@ TEST_CASE("Non-BMP Unicode", "[NONBMP]")
 
         ProjectManager &mocked = pmMock.get();
         pCore->m_projectManager = &mocked;
-        pCore->m_projectManager->m_project = &mockedDoc;
-        pCore->m_projectManager->m_project->m_guideModel = guideModel;
+        mockedDoc.m_guideModel = guideModel;
 
         // We also mock timeline object to spy few functions and mock others
         TimelineItemModel tim(&profile_file, undoStack);
@@ -361,6 +366,130 @@ TEST_CASE("Non-BMP Unicode", "[NONBMP]")
         REQUIRE(xmldata != nullptr);
         CHECK(clipname->text().contains(emojiTestString));
     }
+
+    SECTION("Save project and check profile")
+    {
+
+        // Create document
+        KdenliveDoc document(nullptr);
+        Mock<KdenliveDoc> docMock(document);
+        // When(Method(docMock, getDocumentProperty)).AlwaysDo([](const QString &name, const QString &defaultValue) {
+        //     Q_UNUSED(name) Q_UNUSED(defaultValue)
+        //     qDebug() << "Intercepted call";
+        //     return QStringLiteral("dummyId");
+        // });
+        KdenliveDoc &mockedDoc = docMock.get();
+
+        // We mock the project class so that the undoStack function returns our undoStack, and our mocked document
+        Mock<ProjectManager> pmMock;
+        When(Method(pmMock, undoStack)).AlwaysReturn(undoStack);
+        When(Method(pmMock, cacheDir)).AlwaysReturn(QDir(QStandardPaths::writableLocation(QStandardPaths::CacheLocation)));
+        When(Method(pmMock, current)).AlwaysReturn(&mockedDoc);
+
+        ProjectManager &mocked = pmMock.get();
+        pCore->m_projectManager = &mocked;
+        mockedDoc.m_guideModel = guideModel;
+        pCore->setCurrentProfile("atsc_1080p_25");
+
+        // We also mock timeline object to spy few functions and mock others
+        TimelineItemModel tim(&profile_file, undoStack);
+        Mock<TimelineItemModel> timMock(tim);
+        auto timeline = std::shared_ptr<TimelineItemModel>(&timMock.get(), [](...) {});
+        TimelineItemModel::finishConstruct(timeline, guideModel);
+        mocked.testSetActiveDocument(&mockedDoc, timeline);
+        QDir dir = QDir::temp();
+        std::unordered_map<QString, QString> binIdCorresp;
+        QStringList expandedFolders;
+        QDomDocument doc = mockedDoc.createEmptyDocument(2, 2);
+        QScopedPointer<Mlt::Producer> xmlProd(new Mlt::Producer(profile_file, "xml-string", doc.toString().toUtf8()));
+
+        Mlt::Service s(*xmlProd);
+        Mlt::Tractor tractor(s);
+        binModel->loadBinPlaylist(&tractor, timeline->tractor(), binIdCorresp, expandedFolders, nullptr);
+
+        RESET(timMock)
+
+        TrackModel::construct(timeline, -1, -1, QString(), true);
+        TrackModel::construct(timeline, -1, -1, QString(), true);
+        int tid1 = TrackModel::construct(timeline);
+
+        // Setup timeline audio drop info
+        QMap<int, QString> audioInfo;
+        audioInfo.insert(1, QStringLiteral("stream1"));
+        timeline->m_binAudioTargets = audioInfo;
+        timeline->m_videoTarget = tid1;
+
+        mocked.testSaveFileAs(saveFile.fileName());
+
+        // open the file and check that it contains the correct profile info
+        QFile file(saveFile.fileName());
+        REQUIRE(file.open(QIODevice::ReadOnly));
+        QByteArray contents = file.readAll();
+        QString contentCheck("<property name=\"kdenlive:docproperties.profile\">atsc_1080p_25</property>");
+        if (contents.contains(contentCheck.toUtf8())) {
+            qDebug() << "File contains test string";
+        } else {
+            qDebug() << "File does not contain test string:" << contents;
+        }
+        REQUIRE(contents.contains(contentCheck.toUtf8()));
+        binModel->clean();
+    }
+}
+
+TEST_CASE("Opening Mix", "[OPENMIX]")
+{
+    auto binModel = pCore->projectItemModel();
     binModel->clean();
+
+    // Check that mixes (and reverse mixes) load correctly
+
+    const QString emojiTestString = QString::fromUtf8("test\xF0\x9F\x8D\x99test");
+
+    std::shared_ptr<DocUndoStack> undoStack = std::make_shared<DocUndoStack>(nullptr);
+    std::shared_ptr<MarkerListModel> guideModel = std::make_shared<MarkerListModel>(undoStack);
+
+    SECTION("Load file with a mix")
+    {
+        // We mock the project class so that the undoStack function returns our undoStack, and our mocked document
+        Mock<ProjectManager> pmMock;
+        When(Method(pmMock, undoStack)).AlwaysReturn(undoStack);
+        When(Method(pmMock, cacheDir)).AlwaysReturn(QDir(QStandardPaths::writableLocation(QStandardPaths::CacheLocation)));
+
+        ProjectManager &mocked = pmMock.get();
+
+        // We also mock timeline object to spy few functions and mock others
+
+        // try opening the file as a Kdenlivedoc
+        QUrl openURL = QUrl::fromLocalFile(sourcesPath + "/dataset/test-mix.kdenlive");
+
+        QUndoGroup *undoGroup = new QUndoGroup();
+        undoGroup->addStack(undoStack.get());
+        DocOpenResult openResults = KdenliveDoc::Open(openURL, QDir::temp().path(), undoGroup, false, nullptr);
+        REQUIRE(openResults.isSuccessful() == true);
+
+        std::unique_ptr<KdenliveDoc> openedDoc = openResults.getDocument();
+        When(Method(pmMock, current)).AlwaysReturn(openedDoc.get());
+        /*TimelineItemModel tim(&profile_file, undoStack);
+        Mock<TimelineItemModel> timMock(tim);
+        auto timeline = std::shared_ptr<TimelineItemModel>(&timMock.get(), [](...) {});
+        TimelineItemModel::finishConstruct(timeline, guideModel);
+        mocked.testSetActiveDocument(openedDoc.get(), timeline);*/
+        pCore->m_projectManager = &mocked;
+        pCore->m_projectManager->m_project = openedDoc.get();
+        pCore->m_projectManager->m_project->m_guideModel = guideModel;
+        QDateTime documentDate = QFileInfo(openURL.toLocalFile()).lastModified();
+        pCore->m_projectManager->updateTimeline(0, QString(), QString(), documentDate, 0);
+
+        std::shared_ptr<TimelineItemModel> timeline = pCore->m_projectManager->getTimeline();
+        REQUIRE(timeline->getTracksCount() == 4);
+        int mixtrackId = timeline->getTrackIndexFromPosition(2);
+        REQUIRE(timeline->getTrackById_const(mixtrackId)->mixCount() == 2);
+        int mixtrackId2 = timeline->getTrackIndexFromPosition(3);
+        REQUIRE(timeline->getTrackById_const(mixtrackId2)->mixCount() == 1);
+
+        QDomDocument *newDoc = &openedDoc->m_document;
+        auto producers = newDoc->elementsByTagName(QStringLiteral("producer"));
+        binModel->clean();
+    }
     pCore->m_projectManager = nullptr;
 }
